@@ -37,6 +37,7 @@ impl From<crate::W<C0RE_0_MONTR_ENA_SPEC>> for W {
 #[doc = "Field `CORE_0_AREA_DRAM0_0_RD_ENA` reader - reg_core_0_area_dram0_0_rd_ena"]
 pub struct CORE_0_AREA_DRAM0_0_RD_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_DRAM0_0_RD_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_DRAM0_0_RD_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> CORE_0_AREA_DRAM0_0_RD_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_DRAM0_0_WR_ENA` reader - reg_core_0_area_dram0_0_wr_ena"]
 pub struct CORE_0_AREA_DRAM0_0_WR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_DRAM0_0_WR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_DRAM0_0_WR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> CORE_0_AREA_DRAM0_0_WR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_DRAM0_1_RD_ENA` reader - reg_core_0_area_dram0_1_rd_ena"]
 pub struct CORE_0_AREA_DRAM0_1_RD_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_DRAM0_1_RD_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_DRAM0_1_RD_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> CORE_0_AREA_DRAM0_1_RD_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_DRAM0_1_WR_ENA` reader - reg_core_0_area_dram0_1_wr_ena"]
 pub struct CORE_0_AREA_DRAM0_1_WR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_DRAM0_1_WR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_DRAM0_1_WR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> CORE_0_AREA_DRAM0_1_WR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_PIF_0_RD_ENA` reader - reg_core_0_area_pif_0_rd_ena"]
 pub struct CORE_0_AREA_PIF_0_RD_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_PIF_0_RD_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_PIF_0_RD_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> CORE_0_AREA_PIF_0_RD_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_PIF_0_WR_ENA` reader - reg_core_0_area_pif_0_wr_ena"]
 pub struct CORE_0_AREA_PIF_0_WR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_PIF_0_WR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_PIF_0_WR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> CORE_0_AREA_PIF_0_WR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_PIF_1_RD_ENA` reader - reg_core_0_area_pif_1_rd_ena"]
 pub struct CORE_0_AREA_PIF_1_RD_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_PIF_1_RD_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_PIF_1_RD_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> CORE_0_AREA_PIF_1_RD_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `CORE_0_AREA_PIF_1_WR_ENA` reader - reg_core_0_area_pif_1_wr_ena"]
 pub struct CORE_0_AREA_PIF_1_WR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_AREA_PIF_1_WR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_AREA_PIF_1_WR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> CORE_0_AREA_PIF_1_WR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `CORE_0_SP_SPILL_MIN_ENA` reader - reg_core_0_sp_spill_min_ena"]
 pub struct CORE_0_SP_SPILL_MIN_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_SP_SPILL_MIN_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_SP_SPILL_MIN_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> CORE_0_SP_SPILL_MIN_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `CORE_0_SP_SPILL_MAX_ENA` reader - reg_core_0_sp_spill_max_ena"]
 pub struct CORE_0_SP_SPILL_MAX_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_SP_SPILL_MAX_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_SP_SPILL_MAX_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> CORE_0_SP_SPILL_MAX_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `CORE_0_IRAM0_EXCEPTION_MONITOR_ENA` reader - reg_core_0_iram0_exception_monitor_ena"]
 pub struct CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `CORE_0_DRAM0_EXCEPTION_MONITOR_ENA` reader - reg_core_0_dram0_exception_monitor_ena"]
 pub struct CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R(crate::FieldReader<bool, bool>);
 impl CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,7 +474,7 @@ impl<'a> CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -470,62 +482,62 @@ impl R {
     #[doc = "Bit 0 - reg_core_0_area_dram0_0_rd_ena"]
     #[inline(always)]
     pub fn core_0_area_dram0_0_rd_ena(&self) -> CORE_0_AREA_DRAM0_0_RD_ENA_R {
-        CORE_0_AREA_DRAM0_0_RD_ENA_R::new((self.bits & 0x01) != 0)
+        CORE_0_AREA_DRAM0_0_RD_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - reg_core_0_area_dram0_0_wr_ena"]
     #[inline(always)]
     pub fn core_0_area_dram0_0_wr_ena(&self) -> CORE_0_AREA_DRAM0_0_WR_ENA_R {
-        CORE_0_AREA_DRAM0_0_WR_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        CORE_0_AREA_DRAM0_0_WR_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - reg_core_0_area_dram0_1_rd_ena"]
     #[inline(always)]
     pub fn core_0_area_dram0_1_rd_ena(&self) -> CORE_0_AREA_DRAM0_1_RD_ENA_R {
-        CORE_0_AREA_DRAM0_1_RD_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        CORE_0_AREA_DRAM0_1_RD_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - reg_core_0_area_dram0_1_wr_ena"]
     #[inline(always)]
     pub fn core_0_area_dram0_1_wr_ena(&self) -> CORE_0_AREA_DRAM0_1_WR_ENA_R {
-        CORE_0_AREA_DRAM0_1_WR_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        CORE_0_AREA_DRAM0_1_WR_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - reg_core_0_area_pif_0_rd_ena"]
     #[inline(always)]
     pub fn core_0_area_pif_0_rd_ena(&self) -> CORE_0_AREA_PIF_0_RD_ENA_R {
-        CORE_0_AREA_PIF_0_RD_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        CORE_0_AREA_PIF_0_RD_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - reg_core_0_area_pif_0_wr_ena"]
     #[inline(always)]
     pub fn core_0_area_pif_0_wr_ena(&self) -> CORE_0_AREA_PIF_0_WR_ENA_R {
-        CORE_0_AREA_PIF_0_WR_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        CORE_0_AREA_PIF_0_WR_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - reg_core_0_area_pif_1_rd_ena"]
     #[inline(always)]
     pub fn core_0_area_pif_1_rd_ena(&self) -> CORE_0_AREA_PIF_1_RD_ENA_R {
-        CORE_0_AREA_PIF_1_RD_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        CORE_0_AREA_PIF_1_RD_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - reg_core_0_area_pif_1_wr_ena"]
     #[inline(always)]
     pub fn core_0_area_pif_1_wr_ena(&self) -> CORE_0_AREA_PIF_1_WR_ENA_R {
-        CORE_0_AREA_PIF_1_WR_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        CORE_0_AREA_PIF_1_WR_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - reg_core_0_sp_spill_min_ena"]
     #[inline(always)]
     pub fn core_0_sp_spill_min_ena(&self) -> CORE_0_SP_SPILL_MIN_ENA_R {
-        CORE_0_SP_SPILL_MIN_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        CORE_0_SP_SPILL_MIN_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - reg_core_0_sp_spill_max_ena"]
     #[inline(always)]
     pub fn core_0_sp_spill_max_ena(&self) -> CORE_0_SP_SPILL_MAX_ENA_R {
-        CORE_0_SP_SPILL_MAX_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        CORE_0_SP_SPILL_MAX_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - reg_core_0_iram0_exception_monitor_ena"]
     #[inline(always)]
     pub fn core_0_iram0_exception_monitor_ena(&self) -> CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R {
-        CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        CORE_0_IRAM0_EXCEPTION_MONITOR_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - reg_core_0_dram0_exception_monitor_ena"]
     #[inline(always)]
     pub fn core_0_dram0_exception_monitor_ena(&self) -> CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R {
-        CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        CORE_0_DRAM0_EXCEPTION_MONITOR_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
 }
 impl W {
@@ -596,16 +608,25 @@ impl W {
         self
     }
 }
-#[doc = "ASSIST_DEBUG_C0RE_0_MONTR_ENA_REG\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [c0re_0_montr_ena](index.html) module"]
+#[doc = "ASSIST_DEBUG_C0RE_0_MONTR_ENA_REG\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [c0re_0_montr_ena]
+(index.html) module"]
 pub struct C0RE_0_MONTR_ENA_SPEC;
 impl crate::RegisterSpec for C0RE_0_MONTR_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [c0re_0_montr_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [c0re_0_montr_ena::R]
+(R) reader structure"]
 impl crate::Readable for C0RE_0_MONTR_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [c0re_0_montr_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [c0re_0_montr_ena::W]
+(W) writer structure"]
 impl crate::Writable for C0RE_0_MONTR_ENA_SPEC {
     type Writer = W;
 }
