@@ -37,6 +37,7 @@ impl From<crate::W<INT_ENA_CH2_SPEC>> for W {
 #[doc = "Field `IN_DONE_CH2_INT_ENA` reader - The interrupt enable bit for the IN_DONE_CH_INT interrupt."]
 pub struct IN_DONE_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_DONE_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_DONE_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> IN_DONE_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `IN_SUC_EOF_CH2_INT_ENA` reader - The interrupt enable bit for the IN_SUC_EOF_CH_INT interrupt."]
 pub struct IN_SUC_EOF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_SUC_EOF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_SUC_EOF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> IN_SUC_EOF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `IN_ERR_EOF_CH2_INT_ENA` reader - The interrupt enable bit for the IN_ERR_EOF_CH_INT interrupt."]
 pub struct IN_ERR_EOF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_ERR_EOF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_ERR_EOF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> IN_ERR_EOF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `OUT_DONE_CH2_INT_ENA` reader - The interrupt enable bit for the OUT_DONE_CH_INT interrupt."]
 pub struct OUT_DONE_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_DONE_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_DONE_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> OUT_DONE_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `OUT_EOF_CH2_INT_ENA` reader - The interrupt enable bit for the OUT_EOF_CH_INT interrupt."]
 pub struct OUT_EOF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_EOF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_EOF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> OUT_EOF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `IN_DSCR_ERR_CH2_INT_ENA` reader - The interrupt enable bit for the IN_DSCR_ERR_CH_INT interrupt."]
 pub struct IN_DSCR_ERR_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_DSCR_ERR_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_DSCR_ERR_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> IN_DSCR_ERR_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `OUT_DSCR_ERR_CH2_INT_ENA` reader - The interrupt enable bit for the OUT_DSCR_ERR_CH_INT interrupt."]
 pub struct OUT_DSCR_ERR_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_DSCR_ERR_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_DSCR_ERR_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> OUT_DSCR_ERR_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `IN_DSCR_EMPTY_CH2_INT_ENA` reader - The interrupt enable bit for the IN_DSCR_EMPTY_CH_INT interrupt."]
 pub struct IN_DSCR_EMPTY_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_DSCR_EMPTY_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_DSCR_EMPTY_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> IN_DSCR_EMPTY_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `OUT_TOTAL_EOF_CH2_INT_ENA` reader - The interrupt enable bit for the OUT_TOTAL_EOF_CH_INT interrupt."]
 pub struct OUT_TOTAL_EOF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_TOTAL_EOF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_TOTAL_EOF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> OUT_TOTAL_EOF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `INFIFO_OVF_CH2_INT_ENA` reader - The interrupt enable bit for the INFIFO_OVF_L1_CH_INT interrupt."]
 pub struct INFIFO_OVF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl INFIFO_OVF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INFIFO_OVF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> INFIFO_OVF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `INFIFO_UDF_CH2_INT_ENA` reader - The interrupt enable bit for the INFIFO_UDF_L1_CH_INT interrupt."]
 pub struct INFIFO_UDF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl INFIFO_UDF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         INFIFO_UDF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> INFIFO_UDF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `OUTFIFO_OVF_CH2_INT_ENA` reader - The interrupt enable bit for the OUTFIFO_OVF_L1_CH_INT interrupt."]
 pub struct OUTFIFO_OVF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUTFIFO_OVF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUTFIFO_OVF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> OUTFIFO_OVF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `OUTFIFO_UDF_CH2_INT_ENA` reader - The interrupt enable bit for the OUTFIFO_UDF_L1_CH_INT interrupt."]
 pub struct OUTFIFO_UDF_CH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUTFIFO_UDF_CH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUTFIFO_UDF_CH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -498,7 +511,7 @@ impl<'a> OUTFIFO_UDF_CH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
@@ -506,67 +519,67 @@ impl R {
     #[doc = "Bit 0 - The interrupt enable bit for the IN_DONE_CH_INT interrupt."]
     #[inline(always)]
     pub fn in_done_ch2_int_ena(&self) -> IN_DONE_CH2_INT_ENA_R {
-        IN_DONE_CH2_INT_ENA_R::new((self.bits & 0x01) != 0)
+        IN_DONE_CH2_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - The interrupt enable bit for the IN_SUC_EOF_CH_INT interrupt."]
     #[inline(always)]
     pub fn in_suc_eof_ch2_int_ena(&self) -> IN_SUC_EOF_CH2_INT_ENA_R {
-        IN_SUC_EOF_CH2_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        IN_SUC_EOF_CH2_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - The interrupt enable bit for the IN_ERR_EOF_CH_INT interrupt."]
     #[inline(always)]
     pub fn in_err_eof_ch2_int_ena(&self) -> IN_ERR_EOF_CH2_INT_ENA_R {
-        IN_ERR_EOF_CH2_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        IN_ERR_EOF_CH2_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - The interrupt enable bit for the OUT_DONE_CH_INT interrupt."]
     #[inline(always)]
     pub fn out_done_ch2_int_ena(&self) -> OUT_DONE_CH2_INT_ENA_R {
-        OUT_DONE_CH2_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        OUT_DONE_CH2_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - The interrupt enable bit for the OUT_EOF_CH_INT interrupt."]
     #[inline(always)]
     pub fn out_eof_ch2_int_ena(&self) -> OUT_EOF_CH2_INT_ENA_R {
-        OUT_EOF_CH2_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        OUT_EOF_CH2_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - The interrupt enable bit for the IN_DSCR_ERR_CH_INT interrupt."]
     #[inline(always)]
     pub fn in_dscr_err_ch2_int_ena(&self) -> IN_DSCR_ERR_CH2_INT_ENA_R {
-        IN_DSCR_ERR_CH2_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        IN_DSCR_ERR_CH2_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - The interrupt enable bit for the OUT_DSCR_ERR_CH_INT interrupt."]
     #[inline(always)]
     pub fn out_dscr_err_ch2_int_ena(&self) -> OUT_DSCR_ERR_CH2_INT_ENA_R {
-        OUT_DSCR_ERR_CH2_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        OUT_DSCR_ERR_CH2_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - The interrupt enable bit for the IN_DSCR_EMPTY_CH_INT interrupt."]
     #[inline(always)]
     pub fn in_dscr_empty_ch2_int_ena(&self) -> IN_DSCR_EMPTY_CH2_INT_ENA_R {
-        IN_DSCR_EMPTY_CH2_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        IN_DSCR_EMPTY_CH2_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - The interrupt enable bit for the OUT_TOTAL_EOF_CH_INT interrupt."]
     #[inline(always)]
     pub fn out_total_eof_ch2_int_ena(&self) -> OUT_TOTAL_EOF_CH2_INT_ENA_R {
-        OUT_TOTAL_EOF_CH2_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        OUT_TOTAL_EOF_CH2_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - The interrupt enable bit for the INFIFO_OVF_L1_CH_INT interrupt."]
     #[inline(always)]
     pub fn infifo_ovf_ch2_int_ena(&self) -> INFIFO_OVF_CH2_INT_ENA_R {
-        INFIFO_OVF_CH2_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        INFIFO_OVF_CH2_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - The interrupt enable bit for the INFIFO_UDF_L1_CH_INT interrupt."]
     #[inline(always)]
     pub fn infifo_udf_ch2_int_ena(&self) -> INFIFO_UDF_CH2_INT_ENA_R {
-        INFIFO_UDF_CH2_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        INFIFO_UDF_CH2_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - The interrupt enable bit for the OUTFIFO_OVF_L1_CH_INT interrupt."]
     #[inline(always)]
     pub fn outfifo_ovf_ch2_int_ena(&self) -> OUTFIFO_OVF_CH2_INT_ENA_R {
-        OUTFIFO_OVF_CH2_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        OUTFIFO_OVF_CH2_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - The interrupt enable bit for the OUTFIFO_UDF_L1_CH_INT interrupt."]
     #[inline(always)]
     pub fn outfifo_udf_ch2_int_ena(&self) -> OUTFIFO_UDF_CH2_INT_ENA_R {
-        OUTFIFO_UDF_CH2_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        OUTFIFO_UDF_CH2_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
 }
 impl W {
@@ -642,16 +655,25 @@ impl W {
         self
     }
 }
-#[doc = "DMA_INT_ENA_CH2_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena_ch2](index.html) module"]
+#[doc = "DMA_INT_ENA_CH2_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena_ch2]
+(index.html) module"]
 pub struct INT_ENA_CH2_SPEC;
 impl crate::RegisterSpec for INT_ENA_CH2_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [int_ena_ch2::R](R) reader structure"]
+#[doc = "`read()` method returns [int_ena_ch2::R]
+(R) reader structure"]
 impl crate::Readable for INT_ENA_CH2_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [int_ena_ch2::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [int_ena_ch2::W]
+(W) writer structure"]
 impl crate::Writable for INT_ENA_CH2_SPEC {
     type Writer = W;
 }
