@@ -37,6 +37,7 @@ impl From<crate::W<RX_TDM_CTRL_SPEC>> for W {
 #[doc = "Field `RX_TDM_PDM_CHAN0_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 0. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN0_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN0_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN0_EN_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> RX_TDM_PDM_CHAN0_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN1_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 1. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN1_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN1_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN1_EN_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> RX_TDM_PDM_CHAN1_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN2_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 2. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN2_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN2_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN2_EN_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> RX_TDM_PDM_CHAN2_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN3_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 3. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN3_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN3_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN3_EN_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> RX_TDM_PDM_CHAN3_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN4_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 4. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN4_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN4_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN4_EN_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> RX_TDM_PDM_CHAN4_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN5_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 5. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN5_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN5_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN5_EN_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> RX_TDM_PDM_CHAN5_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN6_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 6. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN6_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN6_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN6_EN_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> RX_TDM_PDM_CHAN6_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_PDM_CHAN7_EN` reader - 1: Enable the valid data input of I2S RX TDM or PDM channel 7. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_PDM_CHAN7_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_PDM_CHAN7_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_PDM_CHAN7_EN_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> RX_TDM_PDM_CHAN7_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN8_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 8. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN8_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN8_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN8_EN_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> RX_TDM_CHAN8_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN9_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 9. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN9_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN9_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN9_EN_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> RX_TDM_CHAN9_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN10_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 10. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN10_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN10_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN10_EN_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> RX_TDM_CHAN10_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN11_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 11. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN11_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN11_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN11_EN_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> RX_TDM_CHAN11_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN12_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 12. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN12_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN12_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN12_EN_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> RX_TDM_CHAN12_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN13_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 13. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN13_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN13_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN13_EN_R(crate::FieldReader::new(bits))
     }
@@ -534,13 +548,14 @@ impl<'a> RX_TDM_CHAN13_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN14_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 14. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN14_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN14_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN14_EN_R(crate::FieldReader::new(bits))
     }
@@ -570,13 +585,14 @@ impl<'a> RX_TDM_CHAN14_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_CHAN15_EN` reader - 1: Enable the valid data input of I2S RX TDM channel 15. 0: Disable, just input 0 in this channel."]
 pub struct RX_TDM_CHAN15_EN_R(crate::FieldReader<bool, bool>);
 impl RX_TDM_CHAN15_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RX_TDM_CHAN15_EN_R(crate::FieldReader::new(bits))
     }
@@ -606,13 +622,14 @@ impl<'a> RX_TDM_CHAN15_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `RX_TDM_TOT_CHAN_NUM` reader - The total channel number of I2S TX TDM mode."]
 pub struct RX_TDM_TOT_CHAN_NUM_R(crate::FieldReader<u8, u8>);
 impl RX_TDM_TOT_CHAN_NUM_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         RX_TDM_TOT_CHAN_NUM_R(crate::FieldReader::new(bits))
     }
@@ -640,82 +657,82 @@ impl R {
     #[doc = "Bit 0 - 1: Enable the valid data input of I2S RX TDM or PDM channel 0. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan0_en(&self) -> RX_TDM_PDM_CHAN0_EN_R {
-        RX_TDM_PDM_CHAN0_EN_R::new((self.bits & 0x01) != 0)
+        RX_TDM_PDM_CHAN0_EN_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - 1: Enable the valid data input of I2S RX TDM or PDM channel 1. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan1_en(&self) -> RX_TDM_PDM_CHAN1_EN_R {
-        RX_TDM_PDM_CHAN1_EN_R::new(((self.bits >> 1) & 0x01) != 0)
+        RX_TDM_PDM_CHAN1_EN_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - 1: Enable the valid data input of I2S RX TDM or PDM channel 2. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan2_en(&self) -> RX_TDM_PDM_CHAN2_EN_R {
-        RX_TDM_PDM_CHAN2_EN_R::new(((self.bits >> 2) & 0x01) != 0)
+        RX_TDM_PDM_CHAN2_EN_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - 1: Enable the valid data input of I2S RX TDM or PDM channel 3. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan3_en(&self) -> RX_TDM_PDM_CHAN3_EN_R {
-        RX_TDM_PDM_CHAN3_EN_R::new(((self.bits >> 3) & 0x01) != 0)
+        RX_TDM_PDM_CHAN3_EN_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - 1: Enable the valid data input of I2S RX TDM or PDM channel 4. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan4_en(&self) -> RX_TDM_PDM_CHAN4_EN_R {
-        RX_TDM_PDM_CHAN4_EN_R::new(((self.bits >> 4) & 0x01) != 0)
+        RX_TDM_PDM_CHAN4_EN_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - 1: Enable the valid data input of I2S RX TDM or PDM channel 5. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan5_en(&self) -> RX_TDM_PDM_CHAN5_EN_R {
-        RX_TDM_PDM_CHAN5_EN_R::new(((self.bits >> 5) & 0x01) != 0)
+        RX_TDM_PDM_CHAN5_EN_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - 1: Enable the valid data input of I2S RX TDM or PDM channel 6. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan6_en(&self) -> RX_TDM_PDM_CHAN6_EN_R {
-        RX_TDM_PDM_CHAN6_EN_R::new(((self.bits >> 6) & 0x01) != 0)
+        RX_TDM_PDM_CHAN6_EN_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - 1: Enable the valid data input of I2S RX TDM or PDM channel 7. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_pdm_chan7_en(&self) -> RX_TDM_PDM_CHAN7_EN_R {
-        RX_TDM_PDM_CHAN7_EN_R::new(((self.bits >> 7) & 0x01) != 0)
+        RX_TDM_PDM_CHAN7_EN_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - 1: Enable the valid data input of I2S RX TDM channel 8. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan8_en(&self) -> RX_TDM_CHAN8_EN_R {
-        RX_TDM_CHAN8_EN_R::new(((self.bits >> 8) & 0x01) != 0)
+        RX_TDM_CHAN8_EN_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - 1: Enable the valid data input of I2S RX TDM channel 9. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan9_en(&self) -> RX_TDM_CHAN9_EN_R {
-        RX_TDM_CHAN9_EN_R::new(((self.bits >> 9) & 0x01) != 0)
+        RX_TDM_CHAN9_EN_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - 1: Enable the valid data input of I2S RX TDM channel 10. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan10_en(&self) -> RX_TDM_CHAN10_EN_R {
-        RX_TDM_CHAN10_EN_R::new(((self.bits >> 10) & 0x01) != 0)
+        RX_TDM_CHAN10_EN_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - 1: Enable the valid data input of I2S RX TDM channel 11. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan11_en(&self) -> RX_TDM_CHAN11_EN_R {
-        RX_TDM_CHAN11_EN_R::new(((self.bits >> 11) & 0x01) != 0)
+        RX_TDM_CHAN11_EN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - 1: Enable the valid data input of I2S RX TDM channel 12. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan12_en(&self) -> RX_TDM_CHAN12_EN_R {
-        RX_TDM_CHAN12_EN_R::new(((self.bits >> 12) & 0x01) != 0)
+        RX_TDM_CHAN12_EN_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - 1: Enable the valid data input of I2S RX TDM channel 13. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan13_en(&self) -> RX_TDM_CHAN13_EN_R {
-        RX_TDM_CHAN13_EN_R::new(((self.bits >> 13) & 0x01) != 0)
+        RX_TDM_CHAN13_EN_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - 1: Enable the valid data input of I2S RX TDM channel 14. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan14_en(&self) -> RX_TDM_CHAN14_EN_R {
-        RX_TDM_CHAN14_EN_R::new(((self.bits >> 14) & 0x01) != 0)
+        RX_TDM_CHAN14_EN_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - 1: Enable the valid data input of I2S RX TDM channel 15. 0: Disable, just input 0 in this channel."]
     #[inline(always)]
     pub fn rx_tdm_chan15_en(&self) -> RX_TDM_CHAN15_EN_R {
-        RX_TDM_CHAN15_EN_R::new(((self.bits >> 15) & 0x01) != 0)
+        RX_TDM_CHAN15_EN_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bits 16:19 - The total channel number of I2S TX TDM mode."]
     #[inline(always)]
@@ -816,16 +833,25 @@ impl W {
         self
     }
 }
-#[doc = "I2S TX TDM mode control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rx_tdm_ctrl](index.html) module"]
+#[doc = "I2S TX TDM mode control register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [rx_tdm_ctrl]
+(index.html) module"]
 pub struct RX_TDM_CTRL_SPEC;
 impl crate::RegisterSpec for RX_TDM_CTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [rx_tdm_ctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [rx_tdm_ctrl::R]
+(R) reader structure"]
 impl crate::Readable for RX_TDM_CTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [rx_tdm_ctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [rx_tdm_ctrl::W]
+(W) writer structure"]
 impl crate::Writable for RX_TDM_CTRL_SPEC {
     type Writer = W;
 }
