@@ -37,6 +37,7 @@ impl From<crate::W<INT_ENA_SPEC>> for W {
 #[doc = "Field `LSTIMER0_OVF_INT_ENA` reader - reg_lstimer0_ovf_int_ena."]
 pub struct LSTIMER0_OVF_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl LSTIMER0_OVF_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSTIMER0_OVF_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> LSTIMER0_OVF_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `LSTIMER1_OVF_INT_ENA` reader - reg_lstimer1_ovf_int_ena."]
 pub struct LSTIMER1_OVF_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl LSTIMER1_OVF_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSTIMER1_OVF_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> LSTIMER1_OVF_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `LSTIMER2_OVF_INT_ENA` reader - reg_lstimer2_ovf_int_ena."]
 pub struct LSTIMER2_OVF_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl LSTIMER2_OVF_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSTIMER2_OVF_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> LSTIMER2_OVF_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `LSTIMER3_OVF_INT_ENA` reader - reg_lstimer3_ovf_int_ena."]
 pub struct LSTIMER3_OVF_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl LSTIMER3_OVF_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSTIMER3_OVF_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> LSTIMER3_OVF_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH0_INT_ENA` reader - reg_duty_chng_end_lsch0_int_ena."]
 pub struct DUTY_CHNG_END_LSCH0_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH0_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH0_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> DUTY_CHNG_END_LSCH0_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH1_INT_ENA` reader - reg_duty_chng_end_lsch1_int_ena."]
 pub struct DUTY_CHNG_END_LSCH1_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH1_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH1_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> DUTY_CHNG_END_LSCH1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH2_INT_ENA` reader - reg_duty_chng_end_lsch2_int_ena."]
 pub struct DUTY_CHNG_END_LSCH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> DUTY_CHNG_END_LSCH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH3_INT_ENA` reader - reg_duty_chng_end_lsch3_int_ena."]
 pub struct DUTY_CHNG_END_LSCH3_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH3_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH3_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> DUTY_CHNG_END_LSCH3_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH4_INT_ENA` reader - reg_duty_chng_end_lsch4_int_ena."]
 pub struct DUTY_CHNG_END_LSCH4_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH4_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH4_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> DUTY_CHNG_END_LSCH4_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `DUTY_CHNG_END_LSCH5_INT_ENA` reader - reg_duty_chng_end_lsch5_int_ena."]
 pub struct DUTY_CHNG_END_LSCH5_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DUTY_CHNG_END_LSCH5_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUTY_CHNG_END_LSCH5_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> DUTY_CHNG_END_LSCH5_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH0_INT_ENA` reader - reg_ovf_cnt_lsch0_int_ena."]
 pub struct OVF_CNT_LSCH0_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH0_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH0_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> OVF_CNT_LSCH0_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH1_INT_ENA` reader - reg_ovf_cnt_lsch1_int_ena."]
 pub struct OVF_CNT_LSCH1_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH1_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH1_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> OVF_CNT_LSCH1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH2_INT_ENA` reader - reg_ovf_cnt_lsch2_int_ena."]
 pub struct OVF_CNT_LSCH2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> OVF_CNT_LSCH2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH3_INT_ENA` reader - reg_ovf_cnt_lsch3_int_ena."]
 pub struct OVF_CNT_LSCH3_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH3_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH3_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -534,13 +548,14 @@ impl<'a> OVF_CNT_LSCH3_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH4_INT_ENA` reader - reg_ovf_cnt_lsch4_int_ena."]
 pub struct OVF_CNT_LSCH4_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH4_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH4_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -570,13 +585,14 @@ impl<'a> OVF_CNT_LSCH4_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `OVF_CNT_LSCH5_INT_ENA` reader - reg_ovf_cnt_lsch5_int_ena."]
 pub struct OVF_CNT_LSCH5_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OVF_CNT_LSCH5_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OVF_CNT_LSCH5_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -606,7 +622,7 @@ impl<'a> OVF_CNT_LSCH5_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
@@ -614,82 +630,82 @@ impl R {
     #[doc = "Bit 0 - reg_lstimer0_ovf_int_ena."]
     #[inline(always)]
     pub fn lstimer0_ovf_int_ena(&self) -> LSTIMER0_OVF_INT_ENA_R {
-        LSTIMER0_OVF_INT_ENA_R::new((self.bits & 0x01) != 0)
+        LSTIMER0_OVF_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - reg_lstimer1_ovf_int_ena."]
     #[inline(always)]
     pub fn lstimer1_ovf_int_ena(&self) -> LSTIMER1_OVF_INT_ENA_R {
-        LSTIMER1_OVF_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        LSTIMER1_OVF_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - reg_lstimer2_ovf_int_ena."]
     #[inline(always)]
     pub fn lstimer2_ovf_int_ena(&self) -> LSTIMER2_OVF_INT_ENA_R {
-        LSTIMER2_OVF_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        LSTIMER2_OVF_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - reg_lstimer3_ovf_int_ena."]
     #[inline(always)]
     pub fn lstimer3_ovf_int_ena(&self) -> LSTIMER3_OVF_INT_ENA_R {
-        LSTIMER3_OVF_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        LSTIMER3_OVF_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - reg_duty_chng_end_lsch0_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch0_int_ena(&self) -> DUTY_CHNG_END_LSCH0_INT_ENA_R {
-        DUTY_CHNG_END_LSCH0_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH0_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - reg_duty_chng_end_lsch1_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch1_int_ena(&self) -> DUTY_CHNG_END_LSCH1_INT_ENA_R {
-        DUTY_CHNG_END_LSCH1_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH1_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - reg_duty_chng_end_lsch2_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch2_int_ena(&self) -> DUTY_CHNG_END_LSCH2_INT_ENA_R {
-        DUTY_CHNG_END_LSCH2_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH2_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - reg_duty_chng_end_lsch3_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch3_int_ena(&self) -> DUTY_CHNG_END_LSCH3_INT_ENA_R {
-        DUTY_CHNG_END_LSCH3_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH3_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - reg_duty_chng_end_lsch4_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch4_int_ena(&self) -> DUTY_CHNG_END_LSCH4_INT_ENA_R {
-        DUTY_CHNG_END_LSCH4_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH4_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - reg_duty_chng_end_lsch5_int_ena."]
     #[inline(always)]
     pub fn duty_chng_end_lsch5_int_ena(&self) -> DUTY_CHNG_END_LSCH5_INT_ENA_R {
-        DUTY_CHNG_END_LSCH5_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        DUTY_CHNG_END_LSCH5_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - reg_ovf_cnt_lsch0_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch0_int_ena(&self) -> OVF_CNT_LSCH0_INT_ENA_R {
-        OVF_CNT_LSCH0_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        OVF_CNT_LSCH0_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - reg_ovf_cnt_lsch1_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch1_int_ena(&self) -> OVF_CNT_LSCH1_INT_ENA_R {
-        OVF_CNT_LSCH1_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        OVF_CNT_LSCH1_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - reg_ovf_cnt_lsch2_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch2_int_ena(&self) -> OVF_CNT_LSCH2_INT_ENA_R {
-        OVF_CNT_LSCH2_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        OVF_CNT_LSCH2_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - reg_ovf_cnt_lsch3_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch3_int_ena(&self) -> OVF_CNT_LSCH3_INT_ENA_R {
-        OVF_CNT_LSCH3_INT_ENA_R::new(((self.bits >> 13) & 0x01) != 0)
+        OVF_CNT_LSCH3_INT_ENA_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - reg_ovf_cnt_lsch4_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch4_int_ena(&self) -> OVF_CNT_LSCH4_INT_ENA_R {
-        OVF_CNT_LSCH4_INT_ENA_R::new(((self.bits >> 14) & 0x01) != 0)
+        OVF_CNT_LSCH4_INT_ENA_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - reg_ovf_cnt_lsch5_int_ena."]
     #[inline(always)]
     pub fn ovf_cnt_lsch5_int_ena(&self) -> OVF_CNT_LSCH5_INT_ENA_R {
-        OVF_CNT_LSCH5_INT_ENA_R::new(((self.bits >> 15) & 0x01) != 0)
+        OVF_CNT_LSCH5_INT_ENA_R::new(((self.bits >> 15) & 1) != 0)
     }
 }
 impl W {
@@ -780,16 +796,25 @@ impl W {
         self
     }
 }
-#[doc = "LEDC_INT_ENA.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena](index.html) module"]
+#[doc = "LEDC_INT_ENA.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena]
+(index.html) module"]
 pub struct INT_ENA_SPEC;
 impl crate::RegisterSpec for INT_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [int_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [int_ena::R]
+(R) reader structure"]
 impl crate::Readable for INT_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [int_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [int_ena::W]
+(W) writer structure"]
 impl crate::Writable for INT_ENA_SPEC {
     type Writer = W;
 }
