@@ -52,7 +52,7 @@ impl<'a> TX_START_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
@@ -74,7 +74,7 @@ impl<'a> MEM_RD_RST_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
@@ -96,13 +96,14 @@ impl<'a> APB_MEM_RST_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `TX_CONTI_MODE_CH0` reader - reg_tx_conti_mode_ch0."]
 pub struct TX_CONTI_MODE_CH0_R(crate::FieldReader<bool, bool>);
 impl TX_CONTI_MODE_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TX_CONTI_MODE_CH0_R(crate::FieldReader::new(bits))
     }
@@ -132,13 +133,14 @@ impl<'a> TX_CONTI_MODE_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `MEM_TX_WRAP_EN_CH0` reader - reg_mem_tx_wrap_en_ch0."]
 pub struct MEM_TX_WRAP_EN_CH0_R(crate::FieldReader<bool, bool>);
 impl MEM_TX_WRAP_EN_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MEM_TX_WRAP_EN_CH0_R(crate::FieldReader::new(bits))
     }
@@ -168,13 +170,14 @@ impl<'a> MEM_TX_WRAP_EN_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `IDLE_OUT_LV_CH0` reader - reg_idle_out_lv_ch0."]
 pub struct IDLE_OUT_LV_CH0_R(crate::FieldReader<bool, bool>);
 impl IDLE_OUT_LV_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IDLE_OUT_LV_CH0_R(crate::FieldReader::new(bits))
     }
@@ -204,13 +207,14 @@ impl<'a> IDLE_OUT_LV_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `IDLE_OUT_EN_CH0` reader - reg_idle_out_en_ch0."]
 pub struct IDLE_OUT_EN_CH0_R(crate::FieldReader<bool, bool>);
 impl IDLE_OUT_EN_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IDLE_OUT_EN_CH0_R(crate::FieldReader::new(bits))
     }
@@ -240,10 +244,25 @@ impl<'a> IDLE_OUT_EN_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
+#[doc = "Field `TX_STOP_CH0` reader - reg_tx_stop_ch0."]
+pub struct TX_STOP_CH0_R(crate::FieldReader<bool, bool>);
+impl TX_STOP_CH0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TX_STOP_CH0_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TX_STOP_CH0_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Field `TX_STOP_CH0` writer - reg_tx_stop_ch0."]
 pub struct TX_STOP_CH0_W<'a> {
     w: &'a mut W,
@@ -262,13 +281,14 @@ impl<'a> TX_STOP_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `DIV_CNT_CH0` reader - reg_div_cnt_ch0."]
 pub struct DIV_CNT_CH0_R(crate::FieldReader<u8, u8>);
 impl DIV_CNT_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         DIV_CNT_CH0_R(crate::FieldReader::new(bits))
     }
@@ -295,6 +315,7 @@ impl<'a> DIV_CNT_CH0_W<'a> {
 #[doc = "Field `MEM_SIZE_CH0` reader - reg_mem_size_ch0."]
 pub struct MEM_SIZE_CH0_R(crate::FieldReader<u8, u8>);
 impl MEM_SIZE_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         MEM_SIZE_CH0_R(crate::FieldReader::new(bits))
     }
@@ -314,13 +335,14 @@ impl<'a> MEM_SIZE_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 16)) | ((value as u32 & 0x07) << 16);
+        self.w.bits = (self.w.bits & !(7 << 16)) | ((value as u32 & 7) << 16);
         self.w
     }
 }
 #[doc = "Field `CARRIER_EFF_EN_CH0` reader - reg_carrier_eff_en_ch0."]
 pub struct CARRIER_EFF_EN_CH0_R(crate::FieldReader<bool, bool>);
 impl CARRIER_EFF_EN_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CARRIER_EFF_EN_CH0_R(crate::FieldReader::new(bits))
     }
@@ -350,13 +372,14 @@ impl<'a> CARRIER_EFF_EN_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `CARRIER_EN_CH0` reader - reg_carrier_en_ch0."]
 pub struct CARRIER_EN_CH0_R(crate::FieldReader<bool, bool>);
 impl CARRIER_EN_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CARRIER_EN_CH0_R(crate::FieldReader::new(bits))
     }
@@ -386,13 +409,14 @@ impl<'a> CARRIER_EN_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `CARRIER_OUT_LV_CH0` reader - reg_carrier_out_lv_ch0."]
 pub struct CARRIER_OUT_LV_CH0_R(crate::FieldReader<bool, bool>);
 impl CARRIER_OUT_LV_CH0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CARRIER_OUT_LV_CH0_R(crate::FieldReader::new(bits))
     }
@@ -422,7 +446,7 @@ impl<'a> CARRIER_OUT_LV_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
@@ -444,7 +468,7 @@ impl<'a> AFIFO_RST_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
@@ -466,7 +490,7 @@ impl<'a> REG_CONF_UPDATE_CH0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -474,22 +498,27 @@ impl R {
     #[doc = "Bit 3 - reg_tx_conti_mode_ch0."]
     #[inline(always)]
     pub fn tx_conti_mode_ch0(&self) -> TX_CONTI_MODE_CH0_R {
-        TX_CONTI_MODE_CH0_R::new(((self.bits >> 3) & 0x01) != 0)
+        TX_CONTI_MODE_CH0_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - reg_mem_tx_wrap_en_ch0."]
     #[inline(always)]
     pub fn mem_tx_wrap_en_ch0(&self) -> MEM_TX_WRAP_EN_CH0_R {
-        MEM_TX_WRAP_EN_CH0_R::new(((self.bits >> 4) & 0x01) != 0)
+        MEM_TX_WRAP_EN_CH0_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - reg_idle_out_lv_ch0."]
     #[inline(always)]
     pub fn idle_out_lv_ch0(&self) -> IDLE_OUT_LV_CH0_R {
-        IDLE_OUT_LV_CH0_R::new(((self.bits >> 5) & 0x01) != 0)
+        IDLE_OUT_LV_CH0_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - reg_idle_out_en_ch0."]
     #[inline(always)]
     pub fn idle_out_en_ch0(&self) -> IDLE_OUT_EN_CH0_R {
-        IDLE_OUT_EN_CH0_R::new(((self.bits >> 6) & 0x01) != 0)
+        IDLE_OUT_EN_CH0_R::new(((self.bits >> 6) & 1) != 0)
+    }
+    #[doc = "Bit 7 - reg_tx_stop_ch0."]
+    #[inline(always)]
+    pub fn tx_stop_ch0(&self) -> TX_STOP_CH0_R {
+        TX_STOP_CH0_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bits 8:15 - reg_div_cnt_ch0."]
     #[inline(always)]
@@ -499,22 +528,22 @@ impl R {
     #[doc = "Bits 16:18 - reg_mem_size_ch0."]
     #[inline(always)]
     pub fn mem_size_ch0(&self) -> MEM_SIZE_CH0_R {
-        MEM_SIZE_CH0_R::new(((self.bits >> 16) & 0x07) as u8)
+        MEM_SIZE_CH0_R::new(((self.bits >> 16) & 7) as u8)
     }
     #[doc = "Bit 20 - reg_carrier_eff_en_ch0."]
     #[inline(always)]
     pub fn carrier_eff_en_ch0(&self) -> CARRIER_EFF_EN_CH0_R {
-        CARRIER_EFF_EN_CH0_R::new(((self.bits >> 20) & 0x01) != 0)
+        CARRIER_EFF_EN_CH0_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - reg_carrier_en_ch0."]
     #[inline(always)]
     pub fn carrier_en_ch0(&self) -> CARRIER_EN_CH0_R {
-        CARRIER_EN_CH0_R::new(((self.bits >> 21) & 0x01) != 0)
+        CARRIER_EN_CH0_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - reg_carrier_out_lv_ch0."]
     #[inline(always)]
     pub fn carrier_out_lv_ch0(&self) -> CARRIER_OUT_LV_CH0_R {
-        CARRIER_OUT_LV_CH0_R::new(((self.bits >> 22) & 0x01) != 0)
+        CARRIER_OUT_LV_CH0_R::new(((self.bits >> 22) & 1) != 0)
     }
 }
 impl W {
@@ -600,16 +629,25 @@ impl W {
         self
     }
 }
-#[doc = "RMT_CH0CONF0_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch0conf0](index.html) module"]
+#[doc = "RMT_CH0CONF0_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch0conf0]
+(index.html) module"]
 pub struct CH0CONF0_SPEC;
 impl crate::RegisterSpec for CH0CONF0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [ch0conf0::R](R) reader structure"]
+#[doc = "`read()` method returns [ch0conf0::R]
+(R) reader structure"]
 impl crate::Readable for CH0CONF0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [ch0conf0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [ch0conf0::W]
+(W) writer structure"]
 impl crate::Writable for CH0CONF0_SPEC {
     type Writer = W;
 }
