@@ -37,6 +37,7 @@ impl From<crate::W<INT_ENA_SPEC>> for W {
 #[doc = "Field `CH0_TX_END_INT_ENA` reader - reg_ch0_tx_end_int_ena."]
 pub struct CH0_TX_END_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH0_TX_END_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH0_TX_END_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> CH0_TX_END_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `CH1_TX_END_INT_ENA` reader - reg_ch1_tx_end_int_ena."]
 pub struct CH1_TX_END_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH1_TX_END_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH1_TX_END_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> CH1_TX_END_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `CH2_RX_END_INT_ENA` reader - reg_ch2_rx_end_int_ena."]
 pub struct CH2_RX_END_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH2_RX_END_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH2_RX_END_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> CH2_RX_END_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `CH3_RX_END_INT_ENA` reader - reg_ch3_rx_end_int_ena."]
 pub struct CH3_RX_END_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH3_RX_END_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH3_RX_END_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> CH3_RX_END_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `CH0_ERR_INT_ENA` reader - reg_ch0_err_int_ena."]
 pub struct CH0_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH0_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH0_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> CH0_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `CH1_ERR_INT_ENA` reader - reg_ch1_err_int_ena."]
 pub struct CH1_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH1_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH1_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> CH1_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `CH2_ERR_INT_ENA` reader - reg_ch2_err_int_ena."]
 pub struct CH2_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH2_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH2_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> CH2_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `CH3_ERR_INT_ENA` reader - reg_ch3_err_int_ena."]
 pub struct CH3_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH3_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH3_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> CH3_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `CH0_TX_THR_EVENT_INT_ENA` reader - reg_ch0_tx_thr_event_int_ena."]
 pub struct CH0_TX_THR_EVENT_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH0_TX_THR_EVENT_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH0_TX_THR_EVENT_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> CH0_TX_THR_EVENT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `CH1_TX_THR_EVENT_INT_ENA` reader - reg_ch1_tx_thr_event_int_ena."]
 pub struct CH1_TX_THR_EVENT_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH1_TX_THR_EVENT_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH1_TX_THR_EVENT_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> CH1_TX_THR_EVENT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `CH2_RX_THR_EVENT_INT_ENA` reader - reg_ch2_rx_thr_event_int_ena."]
 pub struct CH2_RX_THR_EVENT_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH2_RX_THR_EVENT_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH2_RX_THR_EVENT_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> CH2_RX_THR_EVENT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `CH3_RX_THR_EVENT_INT_ENA` reader - reg_ch3_rx_thr_event_int_ena."]
 pub struct CH3_RX_THR_EVENT_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH3_RX_THR_EVENT_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH3_RX_THR_EVENT_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> CH3_RX_THR_EVENT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `CH0_TX_LOOP_INT_ENA` reader - reg_ch0_tx_loop_int_ena."]
 pub struct CH0_TX_LOOP_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH0_TX_LOOP_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH0_TX_LOOP_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> CH0_TX_LOOP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `CH1_TX_LOOP_INT_ENA` reader - reg_ch1_tx_loop_int_ena."]
 pub struct CH1_TX_LOOP_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CH1_TX_LOOP_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CH1_TX_LOOP_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -534,7 +548,7 @@ impl<'a> CH1_TX_LOOP_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
@@ -542,72 +556,72 @@ impl R {
     #[doc = "Bit 0 - reg_ch0_tx_end_int_ena."]
     #[inline(always)]
     pub fn ch0_tx_end_int_ena(&self) -> CH0_TX_END_INT_ENA_R {
-        CH0_TX_END_INT_ENA_R::new((self.bits & 0x01) != 0)
+        CH0_TX_END_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - reg_ch1_tx_end_int_ena."]
     #[inline(always)]
     pub fn ch1_tx_end_int_ena(&self) -> CH1_TX_END_INT_ENA_R {
-        CH1_TX_END_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        CH1_TX_END_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - reg_ch2_rx_end_int_ena."]
     #[inline(always)]
     pub fn ch2_rx_end_int_ena(&self) -> CH2_RX_END_INT_ENA_R {
-        CH2_RX_END_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        CH2_RX_END_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - reg_ch3_rx_end_int_ena."]
     #[inline(always)]
     pub fn ch3_rx_end_int_ena(&self) -> CH3_RX_END_INT_ENA_R {
-        CH3_RX_END_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        CH3_RX_END_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - reg_ch0_err_int_ena."]
     #[inline(always)]
     pub fn ch0_err_int_ena(&self) -> CH0_ERR_INT_ENA_R {
-        CH0_ERR_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        CH0_ERR_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - reg_ch1_err_int_ena."]
     #[inline(always)]
     pub fn ch1_err_int_ena(&self) -> CH1_ERR_INT_ENA_R {
-        CH1_ERR_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        CH1_ERR_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - reg_ch2_err_int_ena."]
     #[inline(always)]
     pub fn ch2_err_int_ena(&self) -> CH2_ERR_INT_ENA_R {
-        CH2_ERR_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        CH2_ERR_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - reg_ch3_err_int_ena."]
     #[inline(always)]
     pub fn ch3_err_int_ena(&self) -> CH3_ERR_INT_ENA_R {
-        CH3_ERR_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        CH3_ERR_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - reg_ch0_tx_thr_event_int_ena."]
     #[inline(always)]
     pub fn ch0_tx_thr_event_int_ena(&self) -> CH0_TX_THR_EVENT_INT_ENA_R {
-        CH0_TX_THR_EVENT_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        CH0_TX_THR_EVENT_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - reg_ch1_tx_thr_event_int_ena."]
     #[inline(always)]
     pub fn ch1_tx_thr_event_int_ena(&self) -> CH1_TX_THR_EVENT_INT_ENA_R {
-        CH1_TX_THR_EVENT_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        CH1_TX_THR_EVENT_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - reg_ch2_rx_thr_event_int_ena."]
     #[inline(always)]
     pub fn ch2_rx_thr_event_int_ena(&self) -> CH2_RX_THR_EVENT_INT_ENA_R {
-        CH2_RX_THR_EVENT_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        CH2_RX_THR_EVENT_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - reg_ch3_rx_thr_event_int_ena."]
     #[inline(always)]
     pub fn ch3_rx_thr_event_int_ena(&self) -> CH3_RX_THR_EVENT_INT_ENA_R {
-        CH3_RX_THR_EVENT_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        CH3_RX_THR_EVENT_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - reg_ch0_tx_loop_int_ena."]
     #[inline(always)]
     pub fn ch0_tx_loop_int_ena(&self) -> CH0_TX_LOOP_INT_ENA_R {
-        CH0_TX_LOOP_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        CH0_TX_LOOP_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - reg_ch1_tx_loop_int_ena."]
     #[inline(always)]
     pub fn ch1_tx_loop_int_ena(&self) -> CH1_TX_LOOP_INT_ENA_R {
-        CH1_TX_LOOP_INT_ENA_R::new(((self.bits >> 13) & 0x01) != 0)
+        CH1_TX_LOOP_INT_ENA_R::new(((self.bits >> 13) & 1) != 0)
     }
 }
 impl W {
@@ -688,16 +702,25 @@ impl W {
         self
     }
 }
-#[doc = "RMT_INT_ENA_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena](index.html) module"]
+#[doc = "RMT_INT_ENA_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena]
+(index.html) module"]
 pub struct INT_ENA_SPEC;
 impl crate::RegisterSpec for INT_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [int_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [int_ena::R]
+(R) reader structure"]
 impl crate::Readable for INT_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [int_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [int_ena::W]
+(W) writer structure"]
 impl crate::Writable for INT_ENA_SPEC {
     type Writer = W;
 }
