@@ -37,6 +37,7 @@ impl From<crate::W<DIG_ISO_SPEC>> for W {
 #[doc = "Field `FORCE_OFF` reader - DIG_ISO force off"]
 pub struct FORCE_OFF_R(crate::FieldReader<bool, bool>);
 impl FORCE_OFF_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FORCE_OFF_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> FORCE_OFF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `FORCE_ON` reader - DIG_ISO force on"]
 pub struct FORCE_ON_R(crate::FieldReader<bool, bool>);
 impl FORCE_ON_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FORCE_ON_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> FORCE_ON_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_AUTOHOLD` reader - read only register to indicate digital pad auto-hold status"]
 pub struct DG_PAD_AUTOHOLD_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_AUTOHOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_AUTOHOLD_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> CLR_DG_PAD_AUTOHOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_AUTOHOLD_EN` reader - digital pad enable auto-hold"]
 pub struct DG_PAD_AUTOHOLD_EN_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_AUTOHOLD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_AUTOHOLD_EN_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> DG_PAD_AUTOHOLD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_FORCE_NOISO` reader - digital pad force no ISO"]
 pub struct DG_PAD_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> DG_PAD_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_FORCE_ISO` reader - digital pad force ISO"]
 pub struct DG_PAD_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> DG_PAD_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_FORCE_UNHOLD` reader - digital pad force un-hold"]
 pub struct DG_PAD_FORCE_UNHOLD_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_FORCE_UNHOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_FORCE_UNHOLD_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> DG_PAD_FORCE_UNHOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `DG_PAD_FORCE_HOLD` reader - digital pad force hold"]
 pub struct DG_PAD_FORCE_HOLD_R(crate::FieldReader<bool, bool>);
 impl DG_PAD_FORCE_HOLD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PAD_FORCE_HOLD_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> DG_PAD_FORCE_HOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `BT_FORCE_ISO` reader - bt force ISO"]
 pub struct BT_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl BT_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BT_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> BT_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `BT_FORCE_NOISO` reader - bt force no ISO"]
 pub struct BT_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl BT_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BT_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> BT_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `DG_PERI_FORCE_ISO` reader - Digital peri force ISO"]
 pub struct DG_PERI_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl DG_PERI_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PERI_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> DG_PERI_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `DG_PERI_FORCE_NOISO` reader - digital peri force no ISO"]
 pub struct DG_PERI_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl DG_PERI_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PERI_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> DG_PERI_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `CPU_TOP_FORCE_ISO` reader - cpu force ISO"]
 pub struct CPU_TOP_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl CPU_TOP_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CPU_TOP_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> CPU_TOP_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `CPU_TOP_FORCE_NOISO` reader - cpu force no ISO"]
 pub struct CPU_TOP_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl CPU_TOP_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CPU_TOP_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -534,13 +548,14 @@ impl<'a> CPU_TOP_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `WIFI_FORCE_ISO` reader - wifi force ISO"]
 pub struct WIFI_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl WIFI_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WIFI_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -570,13 +585,14 @@ impl<'a> WIFI_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
 #[doc = "Field `WIFI_FORCE_NOISO` reader - wifi force no ISO"]
 pub struct WIFI_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl WIFI_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WIFI_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -606,13 +622,14 @@ impl<'a> WIFI_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `DG_WRAP_FORCE_ISO` reader - digital core force ISO"]
 pub struct DG_WRAP_FORCE_ISO_R(crate::FieldReader<bool, bool>);
 impl DG_WRAP_FORCE_ISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_WRAP_FORCE_ISO_R(crate::FieldReader::new(bits))
     }
@@ -642,13 +659,14 @@ impl<'a> DG_WRAP_FORCE_ISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `DG_WRAP_FORCE_NOISO` reader - digital core force no ISO"]
 pub struct DG_WRAP_FORCE_NOISO_R(crate::FieldReader<bool, bool>);
 impl DG_WRAP_FORCE_NOISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_WRAP_FORCE_NOISO_R(crate::FieldReader::new(bits))
     }
@@ -678,7 +696,7 @@ impl<'a> DG_WRAP_FORCE_NOISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -686,92 +704,92 @@ impl R {
     #[doc = "Bit 7 - DIG_ISO force off"]
     #[inline(always)]
     pub fn force_off(&self) -> FORCE_OFF_R {
-        FORCE_OFF_R::new(((self.bits >> 7) & 0x01) != 0)
+        FORCE_OFF_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - DIG_ISO force on"]
     #[inline(always)]
     pub fn force_on(&self) -> FORCE_ON_R {
-        FORCE_ON_R::new(((self.bits >> 8) & 0x01) != 0)
+        FORCE_ON_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - read only register to indicate digital pad auto-hold status"]
     #[inline(always)]
     pub fn dg_pad_autohold(&self) -> DG_PAD_AUTOHOLD_R {
-        DG_PAD_AUTOHOLD_R::new(((self.bits >> 9) & 0x01) != 0)
+        DG_PAD_AUTOHOLD_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 11 - digital pad enable auto-hold"]
     #[inline(always)]
     pub fn dg_pad_autohold_en(&self) -> DG_PAD_AUTOHOLD_EN_R {
-        DG_PAD_AUTOHOLD_EN_R::new(((self.bits >> 11) & 0x01) != 0)
+        DG_PAD_AUTOHOLD_EN_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - digital pad force no ISO"]
     #[inline(always)]
     pub fn dg_pad_force_noiso(&self) -> DG_PAD_FORCE_NOISO_R {
-        DG_PAD_FORCE_NOISO_R::new(((self.bits >> 12) & 0x01) != 0)
+        DG_PAD_FORCE_NOISO_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - digital pad force ISO"]
     #[inline(always)]
     pub fn dg_pad_force_iso(&self) -> DG_PAD_FORCE_ISO_R {
-        DG_PAD_FORCE_ISO_R::new(((self.bits >> 13) & 0x01) != 0)
+        DG_PAD_FORCE_ISO_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - digital pad force un-hold"]
     #[inline(always)]
     pub fn dg_pad_force_unhold(&self) -> DG_PAD_FORCE_UNHOLD_R {
-        DG_PAD_FORCE_UNHOLD_R::new(((self.bits >> 14) & 0x01) != 0)
+        DG_PAD_FORCE_UNHOLD_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - digital pad force hold"]
     #[inline(always)]
     pub fn dg_pad_force_hold(&self) -> DG_PAD_FORCE_HOLD_R {
-        DG_PAD_FORCE_HOLD_R::new(((self.bits >> 15) & 0x01) != 0)
+        DG_PAD_FORCE_HOLD_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 22 - bt force ISO"]
     #[inline(always)]
     pub fn bt_force_iso(&self) -> BT_FORCE_ISO_R {
-        BT_FORCE_ISO_R::new(((self.bits >> 22) & 0x01) != 0)
+        BT_FORCE_ISO_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - bt force no ISO"]
     #[inline(always)]
     pub fn bt_force_noiso(&self) -> BT_FORCE_NOISO_R {
-        BT_FORCE_NOISO_R::new(((self.bits >> 23) & 0x01) != 0)
+        BT_FORCE_NOISO_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - Digital peri force ISO"]
     #[inline(always)]
     pub fn dg_peri_force_iso(&self) -> DG_PERI_FORCE_ISO_R {
-        DG_PERI_FORCE_ISO_R::new(((self.bits >> 24) & 0x01) != 0)
+        DG_PERI_FORCE_ISO_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - digital peri force no ISO"]
     #[inline(always)]
     pub fn dg_peri_force_noiso(&self) -> DG_PERI_FORCE_NOISO_R {
-        DG_PERI_FORCE_NOISO_R::new(((self.bits >> 25) & 0x01) != 0)
+        DG_PERI_FORCE_NOISO_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - cpu force ISO"]
     #[inline(always)]
     pub fn cpu_top_force_iso(&self) -> CPU_TOP_FORCE_ISO_R {
-        CPU_TOP_FORCE_ISO_R::new(((self.bits >> 26) & 0x01) != 0)
+        CPU_TOP_FORCE_ISO_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - cpu force no ISO"]
     #[inline(always)]
     pub fn cpu_top_force_noiso(&self) -> CPU_TOP_FORCE_NOISO_R {
-        CPU_TOP_FORCE_NOISO_R::new(((self.bits >> 27) & 0x01) != 0)
+        CPU_TOP_FORCE_NOISO_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - wifi force ISO"]
     #[inline(always)]
     pub fn wifi_force_iso(&self) -> WIFI_FORCE_ISO_R {
-        WIFI_FORCE_ISO_R::new(((self.bits >> 28) & 0x01) != 0)
+        WIFI_FORCE_ISO_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - wifi force no ISO"]
     #[inline(always)]
     pub fn wifi_force_noiso(&self) -> WIFI_FORCE_NOISO_R {
-        WIFI_FORCE_NOISO_R::new(((self.bits >> 29) & 0x01) != 0)
+        WIFI_FORCE_NOISO_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - digital core force ISO"]
     #[inline(always)]
     pub fn dg_wrap_force_iso(&self) -> DG_WRAP_FORCE_ISO_R {
-        DG_WRAP_FORCE_ISO_R::new(((self.bits >> 30) & 0x01) != 0)
+        DG_WRAP_FORCE_ISO_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - digital core force no ISO"]
     #[inline(always)]
     pub fn dg_wrap_force_noiso(&self) -> DG_WRAP_FORCE_NOISO_R {
-        DG_WRAP_FORCE_NOISO_R::new(((self.bits >> 31) & 0x01) != 0)
+        DG_WRAP_FORCE_NOISO_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -872,16 +890,25 @@ impl W {
         self
     }
 }
-#[doc = "rtc configure register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dig_iso](index.html) module"]
+#[doc = "rtc configure register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dig_iso]
+(index.html) module"]
 pub struct DIG_ISO_SPEC;
 impl crate::RegisterSpec for DIG_ISO_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [dig_iso::R](R) reader structure"]
+#[doc = "`read()` method returns [dig_iso::R]
+(R) reader structure"]
 impl crate::Readable for DIG_ISO_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [dig_iso::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [dig_iso::W]
+(W) writer structure"]
 impl crate::Writable for DIG_ISO_SPEC {
     type Writer = W;
 }
