@@ -37,6 +37,7 @@ impl From<crate::W<DIG_PWC_SPEC>> for W {
 #[doc = "Field `VDD_SPI_PWR_DRV` reader - vdd_spi drv's software value"]
 pub struct VDD_SPI_PWR_DRV_R(crate::FieldReader<u8, u8>);
 impl VDD_SPI_PWR_DRV_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         VDD_SPI_PWR_DRV_R(crate::FieldReader::new(bits))
     }
@@ -56,13 +57,14 @@ impl<'a> VDD_SPI_PWR_DRV_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
+        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
         self.w
     }
 }
 #[doc = "Field `VDD_SPI_PWR_FORCE` reader - vdd_spi drv use software value"]
 pub struct VDD_SPI_PWR_FORCE_R(crate::FieldReader<bool, bool>);
 impl VDD_SPI_PWR_FORCE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         VDD_SPI_PWR_FORCE_R(crate::FieldReader::new(bits))
     }
@@ -92,13 +94,14 @@ impl<'a> VDD_SPI_PWR_FORCE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `LSLP_MEM_FORCE_PD` reader - memories in digital core force PD in sleep"]
 pub struct LSLP_MEM_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl LSLP_MEM_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSLP_MEM_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -128,13 +131,14 @@ impl<'a> LSLP_MEM_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `LSLP_MEM_FORCE_PU` reader - memories in digital core force PU in sleep"]
 pub struct LSLP_MEM_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl LSLP_MEM_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LSLP_MEM_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -164,13 +168,14 @@ impl<'a> LSLP_MEM_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `BT_FORCE_PD` reader - bt force power down"]
 pub struct BT_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl BT_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BT_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -200,13 +205,14 @@ impl<'a> BT_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `BT_FORCE_PU` reader - bt force power up"]
 pub struct BT_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl BT_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BT_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -236,13 +242,14 @@ impl<'a> BT_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `DG_PERI_FORCE_PD` reader - digital peri force power down"]
 pub struct DG_PERI_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl DG_PERI_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PERI_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -272,13 +279,14 @@ impl<'a> DG_PERI_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `DG_PERI_FORCE_PU` reader - digital peri force power up"]
 pub struct DG_PERI_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl DG_PERI_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PERI_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -308,13 +316,14 @@ impl<'a> DG_PERI_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `RTC_FASTMEM_FORCE_LPD` reader - fastmemory retention mode in sleep"]
 pub struct RTC_FASTMEM_FORCE_LPD_R(crate::FieldReader<bool, bool>);
 impl RTC_FASTMEM_FORCE_LPD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RTC_FASTMEM_FORCE_LPD_R(crate::FieldReader::new(bits))
     }
@@ -344,13 +353,14 @@ impl<'a> RTC_FASTMEM_FORCE_LPD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `RTC_FASTMEM_FORCE_LPU` reader - fastmemory donlt entry retention mode in sleep"]
 pub struct RTC_FASTMEM_FORCE_LPU_R(crate::FieldReader<bool, bool>);
 impl RTC_FASTMEM_FORCE_LPU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RTC_FASTMEM_FORCE_LPU_R(crate::FieldReader::new(bits))
     }
@@ -380,13 +390,14 @@ impl<'a> RTC_FASTMEM_FORCE_LPU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `WIFI_FORCE_PD` reader - wifi force power down"]
 pub struct WIFI_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl WIFI_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WIFI_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -416,13 +427,14 @@ impl<'a> WIFI_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `WIFI_FORCE_PU` reader - wifi force power up"]
 pub struct WIFI_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl WIFI_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WIFI_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -452,13 +464,14 @@ impl<'a> WIFI_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `DG_WRAP_FORCE_PD` reader - digital core force power down"]
 pub struct DG_WRAP_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl DG_WRAP_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_WRAP_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -488,13 +501,14 @@ impl<'a> DG_WRAP_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `DG_WRAP_FORCE_PU` reader - digital core force power up"]
 pub struct DG_WRAP_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl DG_WRAP_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_WRAP_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -524,13 +538,14 @@ impl<'a> DG_WRAP_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `CPU_TOP_FORCE_PD` reader - cpu core force power down"]
 pub struct CPU_TOP_FORCE_PD_R(crate::FieldReader<bool, bool>);
 impl CPU_TOP_FORCE_PD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CPU_TOP_FORCE_PD_R(crate::FieldReader::new(bits))
     }
@@ -560,13 +575,14 @@ impl<'a> CPU_TOP_FORCE_PD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `CPU_TOP_FORCE_PU` reader - cpu force power up"]
 pub struct CPU_TOP_FORCE_PU_R(crate::FieldReader<bool, bool>);
 impl CPU_TOP_FORCE_PU_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CPU_TOP_FORCE_PU_R(crate::FieldReader::new(bits))
     }
@@ -596,13 +612,14 @@ impl<'a> CPU_TOP_FORCE_PU_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `BT_PD_EN` reader - enable power down bt in sleep"]
 pub struct BT_PD_EN_R(crate::FieldReader<bool, bool>);
 impl BT_PD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         BT_PD_EN_R(crate::FieldReader::new(bits))
     }
@@ -632,13 +649,14 @@ impl<'a> BT_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `DG_PERI_PD_EN` reader - enable power down digital peri in sleep"]
 pub struct DG_PERI_PD_EN_R(crate::FieldReader<bool, bool>);
 impl DG_PERI_PD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_PERI_PD_EN_R(crate::FieldReader::new(bits))
     }
@@ -668,13 +686,14 @@ impl<'a> DG_PERI_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
 #[doc = "Field `CPU_TOP_PD_EN` reader - enable power down cpu in sleep"]
 pub struct CPU_TOP_PD_EN_R(crate::FieldReader<bool, bool>);
 impl CPU_TOP_PD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CPU_TOP_PD_EN_R(crate::FieldReader::new(bits))
     }
@@ -704,13 +723,14 @@ impl<'a> CPU_TOP_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `WIFI_PD_EN` reader - enable power down wifi in sleep"]
 pub struct WIFI_PD_EN_R(crate::FieldReader<bool, bool>);
 impl WIFI_PD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WIFI_PD_EN_R(crate::FieldReader::new(bits))
     }
@@ -740,13 +760,14 @@ impl<'a> WIFI_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `DG_WRAP_PD_EN` reader - enable power down digital wrap in sleep"]
 pub struct DG_WRAP_PD_EN_R(crate::FieldReader<bool, bool>);
 impl DG_WRAP_PD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DG_WRAP_PD_EN_R(crate::FieldReader::new(bits))
     }
@@ -776,7 +797,7 @@ impl<'a> DG_WRAP_PD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -784,107 +805,107 @@ impl R {
     #[doc = "Bits 0:1 - vdd_spi drv's software value"]
     #[inline(always)]
     pub fn vdd_spi_pwr_drv(&self) -> VDD_SPI_PWR_DRV_R {
-        VDD_SPI_PWR_DRV_R::new((self.bits & 0x03) as u8)
+        VDD_SPI_PWR_DRV_R::new((self.bits & 3) as u8)
     }
     #[doc = "Bit 2 - vdd_spi drv use software value"]
     #[inline(always)]
     pub fn vdd_spi_pwr_force(&self) -> VDD_SPI_PWR_FORCE_R {
-        VDD_SPI_PWR_FORCE_R::new(((self.bits >> 2) & 0x01) != 0)
+        VDD_SPI_PWR_FORCE_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - memories in digital core force PD in sleep"]
     #[inline(always)]
     pub fn lslp_mem_force_pd(&self) -> LSLP_MEM_FORCE_PD_R {
-        LSLP_MEM_FORCE_PD_R::new(((self.bits >> 3) & 0x01) != 0)
+        LSLP_MEM_FORCE_PD_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - memories in digital core force PU in sleep"]
     #[inline(always)]
     pub fn lslp_mem_force_pu(&self) -> LSLP_MEM_FORCE_PU_R {
-        LSLP_MEM_FORCE_PU_R::new(((self.bits >> 4) & 0x01) != 0)
+        LSLP_MEM_FORCE_PU_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 11 - bt force power down"]
     #[inline(always)]
     pub fn bt_force_pd(&self) -> BT_FORCE_PD_R {
-        BT_FORCE_PD_R::new(((self.bits >> 11) & 0x01) != 0)
+        BT_FORCE_PD_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - bt force power up"]
     #[inline(always)]
     pub fn bt_force_pu(&self) -> BT_FORCE_PU_R {
-        BT_FORCE_PU_R::new(((self.bits >> 12) & 0x01) != 0)
+        BT_FORCE_PU_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - digital peri force power down"]
     #[inline(always)]
     pub fn dg_peri_force_pd(&self) -> DG_PERI_FORCE_PD_R {
-        DG_PERI_FORCE_PD_R::new(((self.bits >> 13) & 0x01) != 0)
+        DG_PERI_FORCE_PD_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - digital peri force power up"]
     #[inline(always)]
     pub fn dg_peri_force_pu(&self) -> DG_PERI_FORCE_PU_R {
-        DG_PERI_FORCE_PU_R::new(((self.bits >> 14) & 0x01) != 0)
+        DG_PERI_FORCE_PU_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - fastmemory retention mode in sleep"]
     #[inline(always)]
     pub fn rtc_fastmem_force_lpd(&self) -> RTC_FASTMEM_FORCE_LPD_R {
-        RTC_FASTMEM_FORCE_LPD_R::new(((self.bits >> 15) & 0x01) != 0)
+        RTC_FASTMEM_FORCE_LPD_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - fastmemory donlt entry retention mode in sleep"]
     #[inline(always)]
     pub fn rtc_fastmem_force_lpu(&self) -> RTC_FASTMEM_FORCE_LPU_R {
-        RTC_FASTMEM_FORCE_LPU_R::new(((self.bits >> 16) & 0x01) != 0)
+        RTC_FASTMEM_FORCE_LPU_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - wifi force power down"]
     #[inline(always)]
     pub fn wifi_force_pd(&self) -> WIFI_FORCE_PD_R {
-        WIFI_FORCE_PD_R::new(((self.bits >> 17) & 0x01) != 0)
+        WIFI_FORCE_PD_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - wifi force power up"]
     #[inline(always)]
     pub fn wifi_force_pu(&self) -> WIFI_FORCE_PU_R {
-        WIFI_FORCE_PU_R::new(((self.bits >> 18) & 0x01) != 0)
+        WIFI_FORCE_PU_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - digital core force power down"]
     #[inline(always)]
     pub fn dg_wrap_force_pd(&self) -> DG_WRAP_FORCE_PD_R {
-        DG_WRAP_FORCE_PD_R::new(((self.bits >> 19) & 0x01) != 0)
+        DG_WRAP_FORCE_PD_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - digital core force power up"]
     #[inline(always)]
     pub fn dg_wrap_force_pu(&self) -> DG_WRAP_FORCE_PU_R {
-        DG_WRAP_FORCE_PU_R::new(((self.bits >> 20) & 0x01) != 0)
+        DG_WRAP_FORCE_PU_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - cpu core force power down"]
     #[inline(always)]
     pub fn cpu_top_force_pd(&self) -> CPU_TOP_FORCE_PD_R {
-        CPU_TOP_FORCE_PD_R::new(((self.bits >> 21) & 0x01) != 0)
+        CPU_TOP_FORCE_PD_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - cpu force power up"]
     #[inline(always)]
     pub fn cpu_top_force_pu(&self) -> CPU_TOP_FORCE_PU_R {
-        CPU_TOP_FORCE_PU_R::new(((self.bits >> 22) & 0x01) != 0)
+        CPU_TOP_FORCE_PU_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 27 - enable power down bt in sleep"]
     #[inline(always)]
     pub fn bt_pd_en(&self) -> BT_PD_EN_R {
-        BT_PD_EN_R::new(((self.bits >> 27) & 0x01) != 0)
+        BT_PD_EN_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - enable power down digital peri in sleep"]
     #[inline(always)]
     pub fn dg_peri_pd_en(&self) -> DG_PERI_PD_EN_R {
-        DG_PERI_PD_EN_R::new(((self.bits >> 28) & 0x01) != 0)
+        DG_PERI_PD_EN_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - enable power down cpu in sleep"]
     #[inline(always)]
     pub fn cpu_top_pd_en(&self) -> CPU_TOP_PD_EN_R {
-        CPU_TOP_PD_EN_R::new(((self.bits >> 29) & 0x01) != 0)
+        CPU_TOP_PD_EN_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - enable power down wifi in sleep"]
     #[inline(always)]
     pub fn wifi_pd_en(&self) -> WIFI_PD_EN_R {
-        WIFI_PD_EN_R::new(((self.bits >> 30) & 0x01) != 0)
+        WIFI_PD_EN_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - enable power down digital wrap in sleep"]
     #[inline(always)]
     pub fn dg_wrap_pd_en(&self) -> DG_WRAP_PD_EN_R {
-        DG_WRAP_PD_EN_R::new(((self.bits >> 31) & 0x01) != 0)
+        DG_WRAP_PD_EN_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -1000,16 +1021,25 @@ impl W {
         self
     }
 }
-#[doc = "rtc configure register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dig_pwc](index.html) module"]
+#[doc = "rtc configure register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dig_pwc]
+(index.html) module"]
 pub struct DIG_PWC_SPEC;
 impl crate::RegisterSpec for DIG_PWC_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [dig_pwc::R](R) reader structure"]
+#[doc = "`read()` method returns [dig_pwc::R]
+(R) reader structure"]
 impl crate::Readable for DIG_PWC_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [dig_pwc::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [dig_pwc::W]
+(W) writer structure"]
 impl crate::Writable for DIG_PWC_SPEC {
     type Writer = W;
 }
