@@ -37,6 +37,7 @@ impl From<crate::W<CACHE_FCTRL_SPEC>> for W {
 #[doc = "Field `CACHE_REQ_EN` reader - For SPI0, Cache access enable, 1: enable, 0:disable."]
 pub struct CACHE_REQ_EN_R(crate::FieldReader<bool, bool>);
 impl CACHE_REQ_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CACHE_REQ_EN_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> CACHE_REQ_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `CACHE_USR_ADDR_4BYTE` reader - For SPI0, cache read flash with 4 bytes address, 1: enable, 0:disable."]
 pub struct CACHE_USR_ADDR_4BYTE_R(crate::FieldReader<bool, bool>);
 impl CACHE_USR_ADDR_4BYTE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CACHE_USR_ADDR_4BYTE_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> CACHE_USR_ADDR_4BYTE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `CACHE_FLASH_USR_CMD` reader - For SPI0, cache read flash for user define command, 1: enable, 0:disable."]
 pub struct CACHE_FLASH_USR_CMD_R(crate::FieldReader<bool, bool>);
 impl CACHE_FLASH_USR_CMD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CACHE_FLASH_USR_CMD_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> CACHE_FLASH_USR_CMD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `FDIN_DUAL` reader - For SPI0 flash, din phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
 pub struct FDIN_DUAL_R(crate::FieldReader<bool, bool>);
 impl FDIN_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FDIN_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> FDIN_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `FDOUT_DUAL` reader - For SPI0 flash, dout phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
 pub struct FDOUT_DUAL_R(crate::FieldReader<bool, bool>);
 impl FDOUT_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FDOUT_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> FDOUT_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `FADDR_DUAL` reader - For SPI0 flash, address phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
 pub struct FADDR_DUAL_R(crate::FieldReader<bool, bool>);
 impl FADDR_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FADDR_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> FADDR_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `FDIN_QUAD` reader - For SPI0 flash, din phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
 pub struct FDIN_QUAD_R(crate::FieldReader<bool, bool>);
 impl FDIN_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FDIN_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> FDIN_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `FDOUT_QUAD` reader - For SPI0 flash, dout phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
 pub struct FDOUT_QUAD_R(crate::FieldReader<bool, bool>);
 impl FDOUT_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FDOUT_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> FDOUT_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `FADDR_QUAD` reader - For SPI0 flash, address phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
 pub struct FADDR_QUAD_R(crate::FieldReader<bool, bool>);
 impl FADDR_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FADDR_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -354,7 +363,7 @@ impl<'a> FADDR_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
@@ -362,47 +371,47 @@ impl R {
     #[doc = "Bit 0 - For SPI0, Cache access enable, 1: enable, 0:disable."]
     #[inline(always)]
     pub fn cache_req_en(&self) -> CACHE_REQ_EN_R {
-        CACHE_REQ_EN_R::new((self.bits & 0x01) != 0)
+        CACHE_REQ_EN_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - For SPI0, cache read flash with 4 bytes address, 1: enable, 0:disable."]
     #[inline(always)]
     pub fn cache_usr_addr_4byte(&self) -> CACHE_USR_ADDR_4BYTE_R {
-        CACHE_USR_ADDR_4BYTE_R::new(((self.bits >> 1) & 0x01) != 0)
+        CACHE_USR_ADDR_4BYTE_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - For SPI0, cache read flash for user define command, 1: enable, 0:disable."]
     #[inline(always)]
     pub fn cache_flash_usr_cmd(&self) -> CACHE_FLASH_USR_CMD_R {
-        CACHE_FLASH_USR_CMD_R::new(((self.bits >> 2) & 0x01) != 0)
+        CACHE_FLASH_USR_CMD_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - For SPI0 flash, din phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
     #[inline(always)]
     pub fn fdin_dual(&self) -> FDIN_DUAL_R {
-        FDIN_DUAL_R::new(((self.bits >> 3) & 0x01) != 0)
+        FDIN_DUAL_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - For SPI0 flash, dout phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
     #[inline(always)]
     pub fn fdout_dual(&self) -> FDOUT_DUAL_R {
-        FDOUT_DUAL_R::new(((self.bits >> 4) & 0x01) != 0)
+        FDOUT_DUAL_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - For SPI0 flash, address phase apply 2 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_dio."]
     #[inline(always)]
     pub fn faddr_dual(&self) -> FADDR_DUAL_R {
-        FADDR_DUAL_R::new(((self.bits >> 5) & 0x01) != 0)
+        FADDR_DUAL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - For SPI0 flash, din phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
     #[inline(always)]
     pub fn fdin_quad(&self) -> FDIN_QUAD_R {
-        FDIN_QUAD_R::new(((self.bits >> 6) & 0x01) != 0)
+        FDIN_QUAD_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - For SPI0 flash, dout phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
     #[inline(always)]
     pub fn fdout_quad(&self) -> FDOUT_QUAD_R {
-        FDOUT_QUAD_R::new(((self.bits >> 7) & 0x01) != 0)
+        FDOUT_QUAD_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - For SPI0 flash, address phase apply 4 signals. 1: enable 0: disable. The bit is the same with spi_mem_fread_qio."]
     #[inline(always)]
     pub fn faddr_quad(&self) -> FADDR_QUAD_R {
-        FADDR_QUAD_R::new(((self.bits >> 8) & 0x01) != 0)
+        FADDR_QUAD_R::new(((self.bits >> 8) & 1) != 0)
     }
 }
 impl W {
@@ -458,16 +467,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI0 bit mode control register.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cache_fctrl](index.html) module"]
+#[doc = "SPI0 bit mode control register.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cache_fctrl]
+(index.html) module"]
 pub struct CACHE_FCTRL_SPEC;
 impl crate::RegisterSpec for CACHE_FCTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [cache_fctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [cache_fctrl::R]
+(R) reader structure"]
 impl crate::Readable for CACHE_FCTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [cache_fctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [cache_fctrl::W]
+(W) writer structure"]
 impl crate::Writable for CACHE_FCTRL_SPEC {
     type Writer = W;
 }
