@@ -37,6 +37,7 @@ impl From<crate::W<CTRL_SPEC>> for W {
 #[doc = "Field `FDUMMY_OUT` reader - In the dummy phase the signal level of spi is output by the spi controller."]
 pub struct FDUMMY_OUT_R(crate::FieldReader<bool, bool>);
 impl FDUMMY_OUT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FDUMMY_OUT_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> FDUMMY_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `FCMD_DUAL` reader - Apply 2 signals during command phase 1:enable 0: disable"]
 pub struct FCMD_DUAL_R(crate::FieldReader<bool, bool>);
 impl FCMD_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FCMD_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> FCMD_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `FCMD_QUAD` reader - Apply 4 signals during command phase 1:enable 0: disable"]
 pub struct FCMD_QUAD_R(crate::FieldReader<bool, bool>);
 impl FCMD_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FCMD_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> FCMD_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `FASTRD_MODE` reader - This bit enable the bits: spi_mem_fread_qio, spi_mem_fread_dio, spi_mem_fread_qout and spi_mem_fread_dout. 1: enable 0: disable."]
 pub struct FASTRD_MODE_R(crate::FieldReader<bool, bool>);
 impl FASTRD_MODE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FASTRD_MODE_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> FASTRD_MODE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `FREAD_DUAL` reader - In the read operations, read-data phase apply 2 signals. 1: enable 0: disable."]
 pub struct FREAD_DUAL_R(crate::FieldReader<bool, bool>);
 impl FREAD_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> FREAD_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `Q_POL` reader - The bit is used to set MISO line polarity, 1: high 0, low"]
 pub struct Q_POL_R(crate::FieldReader<bool, bool>);
 impl Q_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         Q_POL_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> Q_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `D_POL` reader - The bit is used to set MOSI line polarity, 1: high 0, low"]
 pub struct D_POL_R(crate::FieldReader<bool, bool>);
 impl D_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         D_POL_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> D_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `FREAD_QUAD` reader - In the read operations read-data phase apply 4 signals. 1: enable 0: disable."]
 pub struct FREAD_QUAD_R(crate::FieldReader<bool, bool>);
 impl FREAD_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> FREAD_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `WP` reader - Write protect signal output when SPI is idle. 1: output high, 0: output low."]
 pub struct WP_R(crate::FieldReader<bool, bool>);
 impl WP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WP_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> WP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `FREAD_DIO` reader - In the read operations address phase and read-data phase apply 2 signals. 1: enable 0: disable."]
 pub struct FREAD_DIO_R(crate::FieldReader<bool, bool>);
 impl FREAD_DIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_DIO_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> FREAD_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `FREAD_QIO` reader - In the read operations address phase and read-data phase apply 4 signals. 1: enable 0: disable."]
 pub struct FREAD_QIO_R(crate::FieldReader<bool, bool>);
 impl FREAD_QIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_QIO_R(crate::FieldReader::new(bits))
     }
@@ -426,7 +437,7 @@ impl<'a> FREAD_QIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
@@ -434,57 +445,57 @@ impl R {
     #[doc = "Bit 3 - In the dummy phase the signal level of spi is output by the spi controller."]
     #[inline(always)]
     pub fn fdummy_out(&self) -> FDUMMY_OUT_R {
-        FDUMMY_OUT_R::new(((self.bits >> 3) & 0x01) != 0)
+        FDUMMY_OUT_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 7 - Apply 2 signals during command phase 1:enable 0: disable"]
     #[inline(always)]
     pub fn fcmd_dual(&self) -> FCMD_DUAL_R {
-        FCMD_DUAL_R::new(((self.bits >> 7) & 0x01) != 0)
+        FCMD_DUAL_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Apply 4 signals during command phase 1:enable 0: disable"]
     #[inline(always)]
     pub fn fcmd_quad(&self) -> FCMD_QUAD_R {
-        FCMD_QUAD_R::new(((self.bits >> 8) & 0x01) != 0)
+        FCMD_QUAD_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 13 - This bit enable the bits: spi_mem_fread_qio, spi_mem_fread_dio, spi_mem_fread_qout and spi_mem_fread_dout. 1: enable 0: disable."]
     #[inline(always)]
     pub fn fastrd_mode(&self) -> FASTRD_MODE_R {
-        FASTRD_MODE_R::new(((self.bits >> 13) & 0x01) != 0)
+        FASTRD_MODE_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - In the read operations, read-data phase apply 2 signals. 1: enable 0: disable."]
     #[inline(always)]
     pub fn fread_dual(&self) -> FREAD_DUAL_R {
-        FREAD_DUAL_R::new(((self.bits >> 14) & 0x01) != 0)
+        FREAD_DUAL_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 18 - The bit is used to set MISO line polarity, 1: high 0, low"]
     #[inline(always)]
     pub fn q_pol(&self) -> Q_POL_R {
-        Q_POL_R::new(((self.bits >> 18) & 0x01) != 0)
+        Q_POL_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - The bit is used to set MOSI line polarity, 1: high 0, low"]
     #[inline(always)]
     pub fn d_pol(&self) -> D_POL_R {
-        D_POL_R::new(((self.bits >> 19) & 0x01) != 0)
+        D_POL_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - In the read operations read-data phase apply 4 signals. 1: enable 0: disable."]
     #[inline(always)]
     pub fn fread_quad(&self) -> FREAD_QUAD_R {
-        FREAD_QUAD_R::new(((self.bits >> 20) & 0x01) != 0)
+        FREAD_QUAD_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - Write protect signal output when SPI is idle. 1: output high, 0: output low."]
     #[inline(always)]
     pub fn wp(&self) -> WP_R {
-        WP_R::new(((self.bits >> 21) & 0x01) != 0)
+        WP_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 23 - In the read operations address phase and read-data phase apply 2 signals. 1: enable 0: disable."]
     #[inline(always)]
     pub fn fread_dio(&self) -> FREAD_DIO_R {
-        FREAD_DIO_R::new(((self.bits >> 23) & 0x01) != 0)
+        FREAD_DIO_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - In the read operations address phase and read-data phase apply 4 signals. 1: enable 0: disable."]
     #[inline(always)]
     pub fn fread_qio(&self) -> FREAD_QIO_R {
-        FREAD_QIO_R::new(((self.bits >> 24) & 0x01) != 0)
+        FREAD_QIO_R::new(((self.bits >> 24) & 1) != 0)
     }
 }
 impl W {
@@ -550,16 +561,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI0 control register.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl](index.html) module"]
+#[doc = "SPI0 control register.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl]
+(index.html) module"]
 pub struct CTRL_SPEC;
 impl crate::RegisterSpec for CTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [ctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [ctrl::R]
+(R) reader structure"]
 impl crate::Readable for CTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [ctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [ctrl::W]
+(W) writer structure"]
 impl crate::Writable for CTRL_SPEC {
     type Writer = W;
 }
