@@ -37,6 +37,7 @@ impl From<crate::W<USER_SPEC>> for W {
 #[doc = "Field `CK_OUT_EDGE` reader - the bit combined with spi_mem_mosi_delay_mode bits to set mosi signal delay mode."]
 pub struct CK_OUT_EDGE_R(crate::FieldReader<bool, bool>);
 impl CK_OUT_EDGE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CK_OUT_EDGE_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> CK_OUT_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `FWRITE_DUAL` reader - In the write operations read-data phase apply 2 signals"]
 pub struct FWRITE_DUAL_R(crate::FieldReader<bool, bool>);
 impl FWRITE_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FWRITE_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> FWRITE_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `FWRITE_QUAD` reader - In the write operations read-data phase apply 4 signals"]
 pub struct FWRITE_QUAD_R(crate::FieldReader<bool, bool>);
 impl FWRITE_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FWRITE_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> FWRITE_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `FWRITE_DIO` reader - In the write operations address phase and read-data phase apply 2 signals."]
 pub struct FWRITE_DIO_R(crate::FieldReader<bool, bool>);
 impl FWRITE_DIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FWRITE_DIO_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> FWRITE_DIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `FWRITE_QIO` reader - In the write operations address phase and read-data phase apply 4 signals."]
 pub struct FWRITE_QIO_R(crate::FieldReader<bool, bool>);
 impl FWRITE_QIO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FWRITE_QIO_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> FWRITE_QIO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `USR_MISO_HIGHPART` reader - read-data phase only access to high-part of the buffer spi_mem_w8~spi_mem_w15. 1: enable 0: disable."]
 pub struct USR_MISO_HIGHPART_R(crate::FieldReader<bool, bool>);
 impl USR_MISO_HIGHPART_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_MISO_HIGHPART_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> USR_MISO_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `USR_MOSI_HIGHPART` reader - write-data phase only access to high-part of the buffer spi_mem_w8~spi_mem_w15. 1: enable 0: disable."]
 pub struct USR_MOSI_HIGHPART_R(crate::FieldReader<bool, bool>);
 impl USR_MOSI_HIGHPART_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_MOSI_HIGHPART_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> USR_MOSI_HIGHPART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `USR_DUMMY_IDLE` reader - SPI clock is disable in dummy phase when the bit is enable."]
 pub struct USR_DUMMY_IDLE_R(crate::FieldReader<bool, bool>);
 impl USR_DUMMY_IDLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_DUMMY_IDLE_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> USR_DUMMY_IDLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `USR_MOSI` reader - This bit enable the write-data phase of an operation."]
 pub struct USR_MOSI_R(crate::FieldReader<bool, bool>);
 impl USR_MOSI_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_MOSI_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> USR_MOSI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `USR_MISO` reader - This bit enable the read-data phase of an operation."]
 pub struct USR_MISO_R(crate::FieldReader<bool, bool>);
 impl USR_MISO_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_MISO_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> USR_MISO_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
 #[doc = "Field `USR_DUMMY` reader - This bit enable the dummy phase of an operation."]
 pub struct USR_DUMMY_R(crate::FieldReader<bool, bool>);
 impl USR_DUMMY_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_DUMMY_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> USR_DUMMY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `USR_ADDR` reader - This bit enable the address phase of an operation."]
 pub struct USR_ADDR_R(crate::FieldReader<bool, bool>);
 impl USR_ADDR_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_ADDR_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> USR_ADDR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `USR_COMMAND` reader - This bit enable the command phase of an operation."]
 pub struct USR_COMMAND_R(crate::FieldReader<bool, bool>);
 impl USR_COMMAND_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USR_COMMAND_R(crate::FieldReader::new(bits))
     }
@@ -498,7 +511,7 @@ impl<'a> USR_COMMAND_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -506,67 +519,67 @@ impl R {
     #[doc = "Bit 9 - the bit combined with spi_mem_mosi_delay_mode bits to set mosi signal delay mode."]
     #[inline(always)]
     pub fn ck_out_edge(&self) -> CK_OUT_EDGE_R {
-        CK_OUT_EDGE_R::new(((self.bits >> 9) & 0x01) != 0)
+        CK_OUT_EDGE_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 12 - In the write operations read-data phase apply 2 signals"]
     #[inline(always)]
     pub fn fwrite_dual(&self) -> FWRITE_DUAL_R {
-        FWRITE_DUAL_R::new(((self.bits >> 12) & 0x01) != 0)
+        FWRITE_DUAL_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - In the write operations read-data phase apply 4 signals"]
     #[inline(always)]
     pub fn fwrite_quad(&self) -> FWRITE_QUAD_R {
-        FWRITE_QUAD_R::new(((self.bits >> 13) & 0x01) != 0)
+        FWRITE_QUAD_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - In the write operations address phase and read-data phase apply 2 signals."]
     #[inline(always)]
     pub fn fwrite_dio(&self) -> FWRITE_DIO_R {
-        FWRITE_DIO_R::new(((self.bits >> 14) & 0x01) != 0)
+        FWRITE_DIO_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - In the write operations address phase and read-data phase apply 4 signals."]
     #[inline(always)]
     pub fn fwrite_qio(&self) -> FWRITE_QIO_R {
-        FWRITE_QIO_R::new(((self.bits >> 15) & 0x01) != 0)
+        FWRITE_QIO_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 24 - read-data phase only access to high-part of the buffer spi_mem_w8~spi_mem_w15. 1: enable 0: disable."]
     #[inline(always)]
     pub fn usr_miso_highpart(&self) -> USR_MISO_HIGHPART_R {
-        USR_MISO_HIGHPART_R::new(((self.bits >> 24) & 0x01) != 0)
+        USR_MISO_HIGHPART_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - write-data phase only access to high-part of the buffer spi_mem_w8~spi_mem_w15. 1: enable 0: disable."]
     #[inline(always)]
     pub fn usr_mosi_highpart(&self) -> USR_MOSI_HIGHPART_R {
-        USR_MOSI_HIGHPART_R::new(((self.bits >> 25) & 0x01) != 0)
+        USR_MOSI_HIGHPART_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - SPI clock is disable in dummy phase when the bit is enable."]
     #[inline(always)]
     pub fn usr_dummy_idle(&self) -> USR_DUMMY_IDLE_R {
-        USR_DUMMY_IDLE_R::new(((self.bits >> 26) & 0x01) != 0)
+        USR_DUMMY_IDLE_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - This bit enable the write-data phase of an operation."]
     #[inline(always)]
     pub fn usr_mosi(&self) -> USR_MOSI_R {
-        USR_MOSI_R::new(((self.bits >> 27) & 0x01) != 0)
+        USR_MOSI_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - This bit enable the read-data phase of an operation."]
     #[inline(always)]
     pub fn usr_miso(&self) -> USR_MISO_R {
-        USR_MISO_R::new(((self.bits >> 28) & 0x01) != 0)
+        USR_MISO_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - This bit enable the dummy phase of an operation."]
     #[inline(always)]
     pub fn usr_dummy(&self) -> USR_DUMMY_R {
-        USR_DUMMY_R::new(((self.bits >> 29) & 0x01) != 0)
+        USR_DUMMY_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - This bit enable the address phase of an operation."]
     #[inline(always)]
     pub fn usr_addr(&self) -> USR_ADDR_R {
-        USR_ADDR_R::new(((self.bits >> 30) & 0x01) != 0)
+        USR_ADDR_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - This bit enable the command phase of an operation."]
     #[inline(always)]
     pub fn usr_command(&self) -> USR_COMMAND_R {
-        USR_COMMAND_R::new(((self.bits >> 31) & 0x01) != 0)
+        USR_COMMAND_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -642,16 +655,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI1 user register.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [user](index.html) module"]
+#[doc = "SPI1 user register.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [user]
+(index.html) module"]
 pub struct USER_SPEC;
 impl crate::RegisterSpec for USER_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [user::R](R) reader structure"]
+#[doc = "`read()` method returns [user::R]
+(R) reader structure"]
 impl crate::Readable for USER_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [user::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [user::W]
+(W) writer structure"]
 impl crate::Writable for USER_SPEC {
     type Writer = W;
 }
