@@ -37,6 +37,7 @@ impl From<crate::W<CTRL_SPEC>> for W {
 #[doc = "Field `DUMMY_OUT` reader - In the dummy phase the signal level of spi is output by the spi controller. Can be configured in CONF state."]
 pub struct DUMMY_OUT_R(crate::FieldReader<bool, bool>);
 impl DUMMY_OUT_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DUMMY_OUT_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> DUMMY_OUT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `FADDR_DUAL` reader - Apply 2 signals during addr phase 1:enable 0: disable. Can be configured in CONF state."]
 pub struct FADDR_DUAL_R(crate::FieldReader<bool, bool>);
 impl FADDR_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FADDR_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> FADDR_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `FADDR_QUAD` reader - Apply 4 signals during addr phase 1:enable 0: disable. Can be configured in CONF state."]
 pub struct FADDR_QUAD_R(crate::FieldReader<bool, bool>);
 impl FADDR_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FADDR_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> FADDR_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `FCMD_DUAL` reader - Apply 2 signals during command phase 1:enable 0: disable. Can be configured in CONF state."]
 pub struct FCMD_DUAL_R(crate::FieldReader<bool, bool>);
 impl FCMD_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FCMD_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> FCMD_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `FCMD_QUAD` reader - Apply 4 signals during command phase 1:enable 0: disable. Can be configured in CONF state."]
 pub struct FCMD_QUAD_R(crate::FieldReader<bool, bool>);
 impl FCMD_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FCMD_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> FCMD_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `FREAD_DUAL` reader - In the read operations, read-data phase apply 2 signals. 1: enable 0: disable. Can be configured in CONF state."]
 pub struct FREAD_DUAL_R(crate::FieldReader<bool, bool>);
 impl FREAD_DUAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_DUAL_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> FREAD_DUAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `FREAD_QUAD` reader - In the read operations read-data phase apply 4 signals. 1: enable 0: disable. Can be configured in CONF state."]
 pub struct FREAD_QUAD_R(crate::FieldReader<bool, bool>);
 impl FREAD_QUAD_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         FREAD_QUAD_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> FREAD_QUAD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `Q_POL` reader - The bit is used to set MISO line polarity, 1: high 0, low. Can be configured in CONF state."]
 pub struct Q_POL_R(crate::FieldReader<bool, bool>);
 impl Q_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         Q_POL_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> Q_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `D_POL` reader - The bit is used to set MOSI line polarity, 1: high 0, low. Can be configured in CONF state."]
 pub struct D_POL_R(crate::FieldReader<bool, bool>);
 impl D_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         D_POL_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> D_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `HOLD_POL` reader - SPI_HOLD output value when SPI is idle. 1: output high, 0: output low. Can be configured in CONF state."]
 pub struct HOLD_POL_R(crate::FieldReader<bool, bool>);
 impl HOLD_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         HOLD_POL_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> HOLD_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `WP_POL` reader - Write protect signal output when SPI is idle. 1: output high, 0: output low. Can be configured in CONF state."]
 pub struct WP_POL_R(crate::FieldReader<bool, bool>);
 impl WP_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WP_POL_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> WP_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `RD_BIT_ORDER` reader - In read-data (MISO) phase 1: LSB first 0: MSB first. Can be configured in CONF state."]
 pub struct RD_BIT_ORDER_R(crate::FieldReader<bool, bool>);
 impl RD_BIT_ORDER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RD_BIT_ORDER_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> RD_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `WR_BIT_ORDER` reader - In command address write-data (MOSI) phases 1: LSB firs 0: MSB first. Can be configured in CONF state."]
 pub struct WR_BIT_ORDER_R(crate::FieldReader<bool, bool>);
 impl WR_BIT_ORDER_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WR_BIT_ORDER_R(crate::FieldReader::new(bits))
     }
@@ -498,7 +511,7 @@ impl<'a> WR_BIT_ORDER_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
@@ -506,67 +519,67 @@ impl R {
     #[doc = "Bit 3 - In the dummy phase the signal level of spi is output by the spi controller. Can be configured in CONF state."]
     #[inline(always)]
     pub fn dummy_out(&self) -> DUMMY_OUT_R {
-        DUMMY_OUT_R::new(((self.bits >> 3) & 0x01) != 0)
+        DUMMY_OUT_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 5 - Apply 2 signals during addr phase 1:enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn faddr_dual(&self) -> FADDR_DUAL_R {
-        FADDR_DUAL_R::new(((self.bits >> 5) & 0x01) != 0)
+        FADDR_DUAL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - Apply 4 signals during addr phase 1:enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn faddr_quad(&self) -> FADDR_QUAD_R {
-        FADDR_QUAD_R::new(((self.bits >> 6) & 0x01) != 0)
+        FADDR_QUAD_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 8 - Apply 2 signals during command phase 1:enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn fcmd_dual(&self) -> FCMD_DUAL_R {
-        FCMD_DUAL_R::new(((self.bits >> 8) & 0x01) != 0)
+        FCMD_DUAL_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Apply 4 signals during command phase 1:enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn fcmd_quad(&self) -> FCMD_QUAD_R {
-        FCMD_QUAD_R::new(((self.bits >> 9) & 0x01) != 0)
+        FCMD_QUAD_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 14 - In the read operations, read-data phase apply 2 signals. 1: enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn fread_dual(&self) -> FREAD_DUAL_R {
-        FREAD_DUAL_R::new(((self.bits >> 14) & 0x01) != 0)
+        FREAD_DUAL_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - In the read operations read-data phase apply 4 signals. 1: enable 0: disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn fread_quad(&self) -> FREAD_QUAD_R {
-        FREAD_QUAD_R::new(((self.bits >> 15) & 0x01) != 0)
+        FREAD_QUAD_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 18 - The bit is used to set MISO line polarity, 1: high 0, low. Can be configured in CONF state."]
     #[inline(always)]
     pub fn q_pol(&self) -> Q_POL_R {
-        Q_POL_R::new(((self.bits >> 18) & 0x01) != 0)
+        Q_POL_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - The bit is used to set MOSI line polarity, 1: high 0, low. Can be configured in CONF state."]
     #[inline(always)]
     pub fn d_pol(&self) -> D_POL_R {
-        D_POL_R::new(((self.bits >> 19) & 0x01) != 0)
+        D_POL_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - SPI_HOLD output value when SPI is idle. 1: output high, 0: output low. Can be configured in CONF state."]
     #[inline(always)]
     pub fn hold_pol(&self) -> HOLD_POL_R {
-        HOLD_POL_R::new(((self.bits >> 20) & 0x01) != 0)
+        HOLD_POL_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - Write protect signal output when SPI is idle. 1: output high, 0: output low. Can be configured in CONF state."]
     #[inline(always)]
     pub fn wp_pol(&self) -> WP_POL_R {
-        WP_POL_R::new(((self.bits >> 21) & 0x01) != 0)
+        WP_POL_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 25 - In read-data (MISO) phase 1: LSB first 0: MSB first. Can be configured in CONF state."]
     #[inline(always)]
     pub fn rd_bit_order(&self) -> RD_BIT_ORDER_R {
-        RD_BIT_ORDER_R::new(((self.bits >> 25) & 0x01) != 0)
+        RD_BIT_ORDER_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - In command address write-data (MOSI) phases 1: LSB firs 0: MSB first. Can be configured in CONF state."]
     #[inline(always)]
     pub fn wr_bit_order(&self) -> WR_BIT_ORDER_R {
-        WR_BIT_ORDER_R::new(((self.bits >> 26) & 0x01) != 0)
+        WR_BIT_ORDER_R::new(((self.bits >> 26) & 1) != 0)
     }
 }
 impl W {
@@ -642,16 +655,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI control register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl](index.html) module"]
+#[doc = "SPI control register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ctrl]
+(index.html) module"]
 pub struct CTRL_SPEC;
 impl crate::RegisterSpec for CTRL_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [ctrl::R](R) reader structure"]
+#[doc = "`read()` method returns [ctrl::R]
+(R) reader structure"]
 impl crate::Readable for CTRL_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [ctrl::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [ctrl::W]
+(W) writer structure"]
 impl crate::Writable for CTRL_SPEC {
     type Writer = W;
 }
