@@ -37,6 +37,7 @@ impl From<crate::W<DMA_INT_ENA_SPEC>> for W {
 #[doc = "Field `DMA_INFIFO_FULL_ERR_INT_ENA` reader - The enable bit for SPI_DMA_INFIFO_FULL_ERR_INT interrupt."]
 pub struct DMA_INFIFO_FULL_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DMA_INFIFO_FULL_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DMA_INFIFO_FULL_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> DMA_INFIFO_FULL_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `DMA_OUTFIFO_EMPTY_ERR_INT_ENA` reader - The enable bit for SPI_DMA_OUTFIFO_EMPTY_ERR_INT interrupt."]
 pub struct DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> DMA_OUTFIFO_EMPTY_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `SLV_EX_QPI_INT_ENA` reader - The enable bit for SPI slave Ex_QPI interrupt."]
 pub struct SLV_EX_QPI_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_EX_QPI_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_EX_QPI_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> SLV_EX_QPI_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `SLV_EN_QPI_INT_ENA` reader - The enable bit for SPI slave En_QPI interrupt."]
 pub struct SLV_EN_QPI_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_EN_QPI_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_EN_QPI_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> SLV_EN_QPI_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `SLV_CMD7_INT_ENA` reader - The enable bit for SPI slave CMD7 interrupt."]
 pub struct SLV_CMD7_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_CMD7_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMD7_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> SLV_CMD7_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `SLV_CMD8_INT_ENA` reader - The enable bit for SPI slave CMD8 interrupt."]
 pub struct SLV_CMD8_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_CMD8_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMD8_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> SLV_CMD8_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `SLV_CMD9_INT_ENA` reader - The enable bit for SPI slave CMD9 interrupt."]
 pub struct SLV_CMD9_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_CMD9_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMD9_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> SLV_CMD9_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `SLV_CMDA_INT_ENA` reader - The enable bit for SPI slave CMDA interrupt."]
 pub struct SLV_CMDA_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_CMDA_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMDA_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> SLV_CMDA_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `SLV_RD_DMA_DONE_INT_ENA` reader - The enable bit for SPI_SLV_RD_DMA_DONE_INT interrupt."]
 pub struct SLV_RD_DMA_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_RD_DMA_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_RD_DMA_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> SLV_RD_DMA_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `SLV_WR_DMA_DONE_INT_ENA` reader - The enable bit for SPI_SLV_WR_DMA_DONE_INT interrupt."]
 pub struct SLV_WR_DMA_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_WR_DMA_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_WR_DMA_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> SLV_WR_DMA_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `SLV_RD_BUF_DONE_INT_ENA` reader - The enable bit for SPI_SLV_RD_BUF_DONE_INT interrupt."]
 pub struct SLV_RD_BUF_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_RD_BUF_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_RD_BUF_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> SLV_RD_BUF_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `SLV_WR_BUF_DONE_INT_ENA` reader - The enable bit for SPI_SLV_WR_BUF_DONE_INT interrupt."]
 pub struct SLV_WR_BUF_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_WR_BUF_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_WR_BUF_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> SLV_WR_BUF_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `TRANS_DONE_INT_ENA` reader - The enable bit for SPI_TRANS_DONE_INT interrupt."]
 pub struct TRANS_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl TRANS_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TRANS_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> TRANS_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `DMA_SEG_TRANS_DONE_INT_ENA` reader - The enable bit for SPI_DMA_SEG_TRANS_DONE_INT interrupt."]
 pub struct DMA_SEG_TRANS_DONE_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl DMA_SEG_TRANS_DONE_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DMA_SEG_TRANS_DONE_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -534,13 +548,14 @@ impl<'a> DMA_SEG_TRANS_DONE_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `SEG_MAGIC_ERR_INT_ENA` reader - The enable bit for SPI_SEG_MAGIC_ERR_INT interrupt."]
 pub struct SEG_MAGIC_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SEG_MAGIC_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SEG_MAGIC_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -570,13 +585,14 @@ impl<'a> SEG_MAGIC_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `SLV_BUF_ADDR_ERR_INT_ENA` reader - The enable bit for SPI_SLV_BUF_ADDR_ERR_INT interrupt."]
 pub struct SLV_BUF_ADDR_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_BUF_ADDR_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_BUF_ADDR_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -606,13 +622,14 @@ impl<'a> SLV_BUF_ADDR_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `SLV_CMD_ERR_INT_ENA` reader - The enable bit for SPI_SLV_CMD_ERR_INT interrupt."]
 pub struct SLV_CMD_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SLV_CMD_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLV_CMD_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -642,13 +659,14 @@ impl<'a> SLV_CMD_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `MST_RX_AFIFO_WFULL_ERR_INT_ENA` reader - The enable bit for SPI_MST_RX_AFIFO_WFULL_ERR_INT interrupt."]
 pub struct MST_RX_AFIFO_WFULL_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl MST_RX_AFIFO_WFULL_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MST_RX_AFIFO_WFULL_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -678,13 +696,14 @@ impl<'a> MST_RX_AFIFO_WFULL_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `MST_TX_AFIFO_REMPTY_ERR_INT_ENA` reader - The enable bit for SPI_MST_TX_AFIFO_REMPTY_ERR_INT interrupt."]
 pub struct MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -714,13 +733,14 @@ impl<'a> MST_TX_AFIFO_REMPTY_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `APP2_INT_ENA` reader - The enable bit for SPI_APP2_INT interrupt."]
 pub struct APP2_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl APP2_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         APP2_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -750,13 +770,14 @@ impl<'a> APP2_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `APP1_INT_ENA` reader - The enable bit for SPI_APP1_INT interrupt."]
 pub struct APP1_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl APP1_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         APP1_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -786,7 +807,7 @@ impl<'a> APP1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
@@ -794,107 +815,107 @@ impl R {
     #[doc = "Bit 0 - The enable bit for SPI_DMA_INFIFO_FULL_ERR_INT interrupt."]
     #[inline(always)]
     pub fn dma_infifo_full_err_int_ena(&self) -> DMA_INFIFO_FULL_ERR_INT_ENA_R {
-        DMA_INFIFO_FULL_ERR_INT_ENA_R::new((self.bits & 0x01) != 0)
+        DMA_INFIFO_FULL_ERR_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - The enable bit for SPI_DMA_OUTFIFO_EMPTY_ERR_INT interrupt."]
     #[inline(always)]
     pub fn dma_outfifo_empty_err_int_ena(&self) -> DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R {
-        DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        DMA_OUTFIFO_EMPTY_ERR_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - The enable bit for SPI slave Ex_QPI interrupt."]
     #[inline(always)]
     pub fn slv_ex_qpi_int_ena(&self) -> SLV_EX_QPI_INT_ENA_R {
-        SLV_EX_QPI_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        SLV_EX_QPI_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - The enable bit for SPI slave En_QPI interrupt."]
     #[inline(always)]
     pub fn slv_en_qpi_int_ena(&self) -> SLV_EN_QPI_INT_ENA_R {
-        SLV_EN_QPI_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        SLV_EN_QPI_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - The enable bit for SPI slave CMD7 interrupt."]
     #[inline(always)]
     pub fn slv_cmd7_int_ena(&self) -> SLV_CMD7_INT_ENA_R {
-        SLV_CMD7_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        SLV_CMD7_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - The enable bit for SPI slave CMD8 interrupt."]
     #[inline(always)]
     pub fn slv_cmd8_int_ena(&self) -> SLV_CMD8_INT_ENA_R {
-        SLV_CMD8_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        SLV_CMD8_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - The enable bit for SPI slave CMD9 interrupt."]
     #[inline(always)]
     pub fn slv_cmd9_int_ena(&self) -> SLV_CMD9_INT_ENA_R {
-        SLV_CMD9_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        SLV_CMD9_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - The enable bit for SPI slave CMDA interrupt."]
     #[inline(always)]
     pub fn slv_cmda_int_ena(&self) -> SLV_CMDA_INT_ENA_R {
-        SLV_CMDA_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        SLV_CMDA_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - The enable bit for SPI_SLV_RD_DMA_DONE_INT interrupt."]
     #[inline(always)]
     pub fn slv_rd_dma_done_int_ena(&self) -> SLV_RD_DMA_DONE_INT_ENA_R {
-        SLV_RD_DMA_DONE_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        SLV_RD_DMA_DONE_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - The enable bit for SPI_SLV_WR_DMA_DONE_INT interrupt."]
     #[inline(always)]
     pub fn slv_wr_dma_done_int_ena(&self) -> SLV_WR_DMA_DONE_INT_ENA_R {
-        SLV_WR_DMA_DONE_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        SLV_WR_DMA_DONE_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - The enable bit for SPI_SLV_RD_BUF_DONE_INT interrupt."]
     #[inline(always)]
     pub fn slv_rd_buf_done_int_ena(&self) -> SLV_RD_BUF_DONE_INT_ENA_R {
-        SLV_RD_BUF_DONE_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        SLV_RD_BUF_DONE_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - The enable bit for SPI_SLV_WR_BUF_DONE_INT interrupt."]
     #[inline(always)]
     pub fn slv_wr_buf_done_int_ena(&self) -> SLV_WR_BUF_DONE_INT_ENA_R {
-        SLV_WR_BUF_DONE_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        SLV_WR_BUF_DONE_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - The enable bit for SPI_TRANS_DONE_INT interrupt."]
     #[inline(always)]
     pub fn trans_done_int_ena(&self) -> TRANS_DONE_INT_ENA_R {
-        TRANS_DONE_INT_ENA_R::new(((self.bits >> 12) & 0x01) != 0)
+        TRANS_DONE_INT_ENA_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - The enable bit for SPI_DMA_SEG_TRANS_DONE_INT interrupt."]
     #[inline(always)]
     pub fn dma_seg_trans_done_int_ena(&self) -> DMA_SEG_TRANS_DONE_INT_ENA_R {
-        DMA_SEG_TRANS_DONE_INT_ENA_R::new(((self.bits >> 13) & 0x01) != 0)
+        DMA_SEG_TRANS_DONE_INT_ENA_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - The enable bit for SPI_SEG_MAGIC_ERR_INT interrupt."]
     #[inline(always)]
     pub fn seg_magic_err_int_ena(&self) -> SEG_MAGIC_ERR_INT_ENA_R {
-        SEG_MAGIC_ERR_INT_ENA_R::new(((self.bits >> 14) & 0x01) != 0)
+        SEG_MAGIC_ERR_INT_ENA_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - The enable bit for SPI_SLV_BUF_ADDR_ERR_INT interrupt."]
     #[inline(always)]
     pub fn slv_buf_addr_err_int_ena(&self) -> SLV_BUF_ADDR_ERR_INT_ENA_R {
-        SLV_BUF_ADDR_ERR_INT_ENA_R::new(((self.bits >> 15) & 0x01) != 0)
+        SLV_BUF_ADDR_ERR_INT_ENA_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - The enable bit for SPI_SLV_CMD_ERR_INT interrupt."]
     #[inline(always)]
     pub fn slv_cmd_err_int_ena(&self) -> SLV_CMD_ERR_INT_ENA_R {
-        SLV_CMD_ERR_INT_ENA_R::new(((self.bits >> 16) & 0x01) != 0)
+        SLV_CMD_ERR_INT_ENA_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - The enable bit for SPI_MST_RX_AFIFO_WFULL_ERR_INT interrupt."]
     #[inline(always)]
     pub fn mst_rx_afifo_wfull_err_int_ena(&self) -> MST_RX_AFIFO_WFULL_ERR_INT_ENA_R {
-        MST_RX_AFIFO_WFULL_ERR_INT_ENA_R::new(((self.bits >> 17) & 0x01) != 0)
+        MST_RX_AFIFO_WFULL_ERR_INT_ENA_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - The enable bit for SPI_MST_TX_AFIFO_REMPTY_ERR_INT interrupt."]
     #[inline(always)]
     pub fn mst_tx_afifo_rempty_err_int_ena(&self) -> MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R {
-        MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R::new(((self.bits >> 18) & 0x01) != 0)
+        MST_TX_AFIFO_REMPTY_ERR_INT_ENA_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - The enable bit for SPI_APP2_INT interrupt."]
     #[inline(always)]
     pub fn app2_int_ena(&self) -> APP2_INT_ENA_R {
-        APP2_INT_ENA_R::new(((self.bits >> 19) & 0x01) != 0)
+        APP2_INT_ENA_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - The enable bit for SPI_APP1_INT interrupt."]
     #[inline(always)]
     pub fn app1_int_ena(&self) -> APP1_INT_ENA_R {
-        APP1_INT_ENA_R::new(((self.bits >> 20) & 0x01) != 0)
+        APP1_INT_ENA_R::new(((self.bits >> 20) & 1) != 0)
     }
 }
 impl W {
@@ -1010,16 +1031,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI DMA interrupt enable register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_int_ena](index.html) module"]
+#[doc = "SPI DMA interrupt enable register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dma_int_ena]
+(index.html) module"]
 pub struct DMA_INT_ENA_SPEC;
 impl crate::RegisterSpec for DMA_INT_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [dma_int_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [dma_int_ena::R]
+(R) reader structure"]
 impl crate::Readable for DMA_INT_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [dma_int_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [dma_int_ena::W]
+(W) writer structure"]
 impl crate::Writable for DMA_INT_ENA_SPEC {
     type Writer = W;
 }
