@@ -37,6 +37,7 @@ impl From<crate::W<MISC_SPEC>> for W {
 #[doc = "Field `CS0_DIS` reader - SPI CS0 pin enable, 1: disable CS0, 0: spi_cs0 signal is from/to CS0 pin. Can be configured in CONF state."]
 pub struct CS0_DIS_R(crate::FieldReader<bool, bool>);
 impl CS0_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS0_DIS_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> CS0_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `CS1_DIS` reader - SPI CS1 pin enable, 1: disable CS1, 0: spi_cs1 signal is from/to CS1 pin. Can be configured in CONF state."]
 pub struct CS1_DIS_R(crate::FieldReader<bool, bool>);
 impl CS1_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS1_DIS_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> CS1_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `CS2_DIS` reader - SPI CS2 pin enable, 1: disable CS2, 0: spi_cs2 signal is from/to CS2 pin. Can be configured in CONF state."]
 pub struct CS2_DIS_R(crate::FieldReader<bool, bool>);
 impl CS2_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS2_DIS_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> CS2_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `CS3_DIS` reader - SPI CS3 pin enable, 1: disable CS3, 0: spi_cs3 signal is from/to CS3 pin. Can be configured in CONF state."]
 pub struct CS3_DIS_R(crate::FieldReader<bool, bool>);
 impl CS3_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS3_DIS_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> CS3_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `CS4_DIS` reader - SPI CS4 pin enable, 1: disable CS4, 0: spi_cs4 signal is from/to CS4 pin. Can be configured in CONF state."]
 pub struct CS4_DIS_R(crate::FieldReader<bool, bool>);
 impl CS4_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS4_DIS_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> CS4_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `CS5_DIS` reader - SPI CS5 pin enable, 1: disable CS5, 0: spi_cs5 signal is from/to CS5 pin. Can be configured in CONF state."]
 pub struct CS5_DIS_R(crate::FieldReader<bool, bool>);
 impl CS5_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS5_DIS_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> CS5_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `CK_DIS` reader - 1: spi clk out disable, 0: spi clk out enable. Can be configured in CONF state."]
 pub struct CK_DIS_R(crate::FieldReader<bool, bool>);
 impl CK_DIS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CK_DIS_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> CK_DIS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `MASTER_CS_POL` reader - In the master mode the bits are the polarity of spi cs line, the value is equivalent to spi_cs ^ spi_master_cs_pol. Can be configured in CONF state."]
 pub struct MASTER_CS_POL_R(crate::FieldReader<u8, u8>);
 impl MASTER_CS_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         MASTER_CS_POL_R(crate::FieldReader::new(bits))
     }
@@ -315,6 +323,7 @@ impl<'a> MASTER_CS_POL_W<'a> {
 #[doc = "Field `SLAVE_CS_POL` reader - spi slave input cs polarity select. 1: inv 0: not change. Can be configured in CONF state."]
 pub struct SLAVE_CS_POL_R(crate::FieldReader<bool, bool>);
 impl SLAVE_CS_POL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SLAVE_CS_POL_R(crate::FieldReader::new(bits))
     }
@@ -344,13 +353,14 @@ impl<'a> SLAVE_CS_POL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `CK_IDLE_EDGE` reader - 1: spi clk line is high when idle 0: spi clk line is low when idle. Can be configured in CONF state."]
 pub struct CK_IDLE_EDGE_R(crate::FieldReader<bool, bool>);
 impl CK_IDLE_EDGE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CK_IDLE_EDGE_R(crate::FieldReader::new(bits))
     }
@@ -380,13 +390,14 @@ impl<'a> CK_IDLE_EDGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `CS_KEEP_ACTIVE` reader - spi cs line keep low when the bit is set. Can be configured in CONF state."]
 pub struct CS_KEEP_ACTIVE_R(crate::FieldReader<bool, bool>);
 impl CS_KEEP_ACTIVE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CS_KEEP_ACTIVE_R(crate::FieldReader::new(bits))
     }
@@ -416,13 +427,14 @@ impl<'a> CS_KEEP_ACTIVE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `QUAD_DIN_PIN_SWAP` reader - 1: spi quad input swap enable 0: spi quad input swap disable. Can be configured in CONF state."]
 pub struct QUAD_DIN_PIN_SWAP_R(crate::FieldReader<bool, bool>);
 impl QUAD_DIN_PIN_SWAP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         QUAD_DIN_PIN_SWAP_R(crate::FieldReader::new(bits))
     }
@@ -452,7 +464,7 @@ impl<'a> QUAD_DIN_PIN_SWAP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -460,37 +472,37 @@ impl R {
     #[doc = "Bit 0 - SPI CS0 pin enable, 1: disable CS0, 0: spi_cs0 signal is from/to CS0 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs0_dis(&self) -> CS0_DIS_R {
-        CS0_DIS_R::new((self.bits & 0x01) != 0)
+        CS0_DIS_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - SPI CS1 pin enable, 1: disable CS1, 0: spi_cs1 signal is from/to CS1 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs1_dis(&self) -> CS1_DIS_R {
-        CS1_DIS_R::new(((self.bits >> 1) & 0x01) != 0)
+        CS1_DIS_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - SPI CS2 pin enable, 1: disable CS2, 0: spi_cs2 signal is from/to CS2 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs2_dis(&self) -> CS2_DIS_R {
-        CS2_DIS_R::new(((self.bits >> 2) & 0x01) != 0)
+        CS2_DIS_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - SPI CS3 pin enable, 1: disable CS3, 0: spi_cs3 signal is from/to CS3 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs3_dis(&self) -> CS3_DIS_R {
-        CS3_DIS_R::new(((self.bits >> 3) & 0x01) != 0)
+        CS3_DIS_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - SPI CS4 pin enable, 1: disable CS4, 0: spi_cs4 signal is from/to CS4 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs4_dis(&self) -> CS4_DIS_R {
-        CS4_DIS_R::new(((self.bits >> 4) & 0x01) != 0)
+        CS4_DIS_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - SPI CS5 pin enable, 1: disable CS5, 0: spi_cs5 signal is from/to CS5 pin. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs5_dis(&self) -> CS5_DIS_R {
-        CS5_DIS_R::new(((self.bits >> 5) & 0x01) != 0)
+        CS5_DIS_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - 1: spi clk out disable, 0: spi clk out enable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn ck_dis(&self) -> CK_DIS_R {
-        CK_DIS_R::new(((self.bits >> 6) & 0x01) != 0)
+        CK_DIS_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bits 7:12 - In the master mode the bits are the polarity of spi cs line, the value is equivalent to spi_cs ^ spi_master_cs_pol. Can be configured in CONF state."]
     #[inline(always)]
@@ -500,22 +512,22 @@ impl R {
     #[doc = "Bit 23 - spi slave input cs polarity select. 1: inv 0: not change. Can be configured in CONF state."]
     #[inline(always)]
     pub fn slave_cs_pol(&self) -> SLAVE_CS_POL_R {
-        SLAVE_CS_POL_R::new(((self.bits >> 23) & 0x01) != 0)
+        SLAVE_CS_POL_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 29 - 1: spi clk line is high when idle 0: spi clk line is low when idle. Can be configured in CONF state."]
     #[inline(always)]
     pub fn ck_idle_edge(&self) -> CK_IDLE_EDGE_R {
-        CK_IDLE_EDGE_R::new(((self.bits >> 29) & 0x01) != 0)
+        CK_IDLE_EDGE_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - spi cs line keep low when the bit is set. Can be configured in CONF state."]
     #[inline(always)]
     pub fn cs_keep_active(&self) -> CS_KEEP_ACTIVE_R {
-        CS_KEEP_ACTIVE_R::new(((self.bits >> 30) & 0x01) != 0)
+        CS_KEEP_ACTIVE_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - 1: spi quad input swap enable 0: spi quad input swap disable. Can be configured in CONF state."]
     #[inline(always)]
     pub fn quad_din_pin_swap(&self) -> QUAD_DIN_PIN_SWAP_R {
-        QUAD_DIN_PIN_SWAP_R::new(((self.bits >> 31) & 0x01) != 0)
+        QUAD_DIN_PIN_SWAP_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -586,16 +598,25 @@ impl W {
         self
     }
 }
-#[doc = "SPI misc register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [misc](index.html) module"]
+#[doc = "SPI misc register\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [misc]
+(index.html) module"]
 pub struct MISC_SPEC;
 impl crate::RegisterSpec for MISC_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [misc::R](R) reader structure"]
+#[doc = "`read()` method returns [misc::R]
+(R) reader structure"]
 impl crate::Readable for MISC_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [misc::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [misc::W]
+(W) writer structure"]
 impl crate::Writable for MISC_SPEC {
     type Writer = W;
 }
