@@ -37,6 +37,7 @@ impl From<crate::W<PERIP_RST_EN0_SPEC>> for W {
 #[doc = "Field `TIMERS_RST` reader - reg_timers_rst"]
 pub struct TIMERS_RST_R(crate::FieldReader<bool, bool>);
 impl TIMERS_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TIMERS_RST_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> TIMERS_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `SPI01_RST` reader - reg_spi01_rst"]
 pub struct SPI01_RST_R(crate::FieldReader<bool, bool>);
 impl SPI01_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI01_RST_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> SPI01_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `UART_RST` reader - reg_uart_rst"]
 pub struct UART_RST_R(crate::FieldReader<bool, bool>);
 impl UART_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_RST_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> UART_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `WDG_RST` reader - reg_wdg_rst"]
 pub struct WDG_RST_R(crate::FieldReader<bool, bool>);
 impl WDG_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDG_RST_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> WDG_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `I2S0_RST` reader - reg_i2s0_rst"]
 pub struct I2S0_RST_R(crate::FieldReader<bool, bool>);
 impl I2S0_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S0_RST_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> I2S0_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `UART1_RST` reader - reg_uart1_rst"]
 pub struct UART1_RST_R(crate::FieldReader<bool, bool>);
 impl UART1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART1_RST_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> UART1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `SPI2_RST` reader - reg_spi2_rst"]
 pub struct SPI2_RST_R(crate::FieldReader<bool, bool>);
 impl SPI2_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI2_RST_R(crate::FieldReader::new(bits))
     }
@@ -282,29 +289,30 @@ impl<'a> SPI2_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
-#[doc = "Field `EXT0_RST` reader - reg_ext0_rst"]
-pub struct EXT0_RST_R(crate::FieldReader<bool, bool>);
-impl EXT0_RST_R {
+#[doc = "Field `I2C_EXT0_RST` reader - reg_ext0_rst"]
+pub struct I2C_EXT0_RST_R(crate::FieldReader<bool, bool>);
+impl I2C_EXT0_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
-        EXT0_RST_R(crate::FieldReader::new(bits))
+        I2C_EXT0_RST_R(crate::FieldReader::new(bits))
     }
 }
-impl core::ops::Deref for EXT0_RST_R {
+impl core::ops::Deref for I2C_EXT0_RST_R {
     type Target = crate::FieldReader<bool, bool>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
     }
 }
-#[doc = "Field `EXT0_RST` writer - reg_ext0_rst"]
-pub struct EXT0_RST_W<'a> {
+#[doc = "Field `I2C_EXT0_RST` writer - reg_ext0_rst"]
+pub struct I2C_EXT0_RST_W<'a> {
     w: &'a mut W,
 }
-impl<'a> EXT0_RST_W<'a> {
+impl<'a> I2C_EXT0_RST_W<'a> {
     #[doc = r"Sets the field bit"]
     #[inline(always)]
     pub fn set_bit(self) -> &'a mut W {
@@ -318,13 +326,14 @@ impl<'a> EXT0_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `UHCI0_RST` reader - reg_uhci0_rst"]
 pub struct UHCI0_RST_R(crate::FieldReader<bool, bool>);
 impl UHCI0_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UHCI0_RST_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> UHCI0_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `RMT_RST` reader - reg_rmt_rst"]
 pub struct RMT_RST_R(crate::FieldReader<bool, bool>);
 impl RMT_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         RMT_RST_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> RMT_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `PCNT_RST` reader - reg_pcnt_rst"]
 pub struct PCNT_RST_R(crate::FieldReader<bool, bool>);
 impl PCNT_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PCNT_RST_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> PCNT_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `LEDC_RST` reader - reg_ledc_rst"]
 pub struct LEDC_RST_R(crate::FieldReader<bool, bool>);
 impl LEDC_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         LEDC_RST_R(crate::FieldReader::new(bits))
     }
@@ -462,13 +474,14 @@ impl<'a> LEDC_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `UHCI1_RST` reader - reg_uhci1_rst"]
 pub struct UHCI1_RST_R(crate::FieldReader<bool, bool>);
 impl UHCI1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UHCI1_RST_R(crate::FieldReader::new(bits))
     }
@@ -498,13 +511,14 @@ impl<'a> UHCI1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `TIMERGROUP_RST` reader - reg_timergroup_rst"]
 pub struct TIMERGROUP_RST_R(crate::FieldReader<bool, bool>);
 impl TIMERGROUP_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TIMERGROUP_RST_R(crate::FieldReader::new(bits))
     }
@@ -534,13 +548,14 @@ impl<'a> TIMERGROUP_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `EFUSE_RST` reader - reg_efuse_rst"]
 pub struct EFUSE_RST_R(crate::FieldReader<bool, bool>);
 impl EFUSE_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EFUSE_RST_R(crate::FieldReader::new(bits))
     }
@@ -570,13 +585,14 @@ impl<'a> EFUSE_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `TIMERGROUP1_RST` reader - reg_timergroup1_rst"]
 pub struct TIMERGROUP1_RST_R(crate::FieldReader<bool, bool>);
 impl TIMERGROUP1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         TIMERGROUP1_RST_R(crate::FieldReader::new(bits))
     }
@@ -606,13 +622,14 @@ impl<'a> TIMERGROUP1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
         self.w
     }
 }
 #[doc = "Field `SPI3_RST` reader - reg_spi3_rst"]
 pub struct SPI3_RST_R(crate::FieldReader<bool, bool>);
 impl SPI3_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI3_RST_R(crate::FieldReader::new(bits))
     }
@@ -642,13 +659,14 @@ impl<'a> SPI3_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
         self.w
     }
 }
 #[doc = "Field `PWM0_RST` reader - reg_pwm0_rst"]
 pub struct PWM0_RST_R(crate::FieldReader<bool, bool>);
 impl PWM0_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PWM0_RST_R(crate::FieldReader::new(bits))
     }
@@ -678,13 +696,14 @@ impl<'a> PWM0_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
         self.w
     }
 }
 #[doc = "Field `EXT1_RST` reader - reg_ext1_rst"]
 pub struct EXT1_RST_R(crate::FieldReader<bool, bool>);
 impl EXT1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EXT1_RST_R(crate::FieldReader::new(bits))
     }
@@ -714,13 +733,14 @@ impl<'a> EXT1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
         self.w
     }
 }
 #[doc = "Field `CAN_RST` reader - reg_can_rst"]
 pub struct CAN_RST_R(crate::FieldReader<bool, bool>);
 impl CAN_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CAN_RST_R(crate::FieldReader::new(bits))
     }
@@ -750,13 +770,14 @@ impl<'a> CAN_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
         self.w
     }
 }
 #[doc = "Field `PWM1_RST` reader - reg_pwm1_rst"]
 pub struct PWM1_RST_R(crate::FieldReader<bool, bool>);
 impl PWM1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PWM1_RST_R(crate::FieldReader::new(bits))
     }
@@ -786,13 +807,14 @@ impl<'a> PWM1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
         self.w
     }
 }
 #[doc = "Field `I2S1_RST` reader - reg_i2s1_rst"]
 pub struct I2S1_RST_R(crate::FieldReader<bool, bool>);
 impl I2S1_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         I2S1_RST_R(crate::FieldReader::new(bits))
     }
@@ -822,13 +844,14 @@ impl<'a> I2S1_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
 #[doc = "Field `SPI2_DMA_RST` reader - reg_spi2_dma_rst"]
 pub struct SPI2_DMA_RST_R(crate::FieldReader<bool, bool>);
 impl SPI2_DMA_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI2_DMA_RST_R(crate::FieldReader::new(bits))
     }
@@ -858,13 +881,14 @@ impl<'a> SPI2_DMA_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `USB_DEVICE_RST` reader - reg_usb_device_rst"]
 pub struct USB_DEVICE_RST_R(crate::FieldReader<bool, bool>);
 impl USB_DEVICE_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USB_DEVICE_RST_R(crate::FieldReader::new(bits))
     }
@@ -894,13 +918,14 @@ impl<'a> USB_DEVICE_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
         self.w
     }
 }
 #[doc = "Field `UART_MEM_RST` reader - reg_uart_mem_rst"]
 pub struct UART_MEM_RST_R(crate::FieldReader<bool, bool>);
 impl UART_MEM_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         UART_MEM_RST_R(crate::FieldReader::new(bits))
     }
@@ -930,13 +955,14 @@ impl<'a> UART_MEM_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
+        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
         self.w
     }
 }
 #[doc = "Field `PWM2_RST` reader - reg_pwm2_rst"]
 pub struct PWM2_RST_R(crate::FieldReader<bool, bool>);
 impl PWM2_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PWM2_RST_R(crate::FieldReader::new(bits))
     }
@@ -966,13 +992,14 @@ impl<'a> PWM2_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
+        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
         self.w
     }
 }
 #[doc = "Field `PWM3_RST` reader - reg_pwm3_rst"]
 pub struct PWM3_RST_R(crate::FieldReader<bool, bool>);
 impl PWM3_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PWM3_RST_R(crate::FieldReader::new(bits))
     }
@@ -1002,13 +1029,14 @@ impl<'a> PWM3_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 26)) | ((value as u32 & 0x01) << 26);
+        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
         self.w
     }
 }
 #[doc = "Field `SPI3_DMA_RST` reader - reg_spi3_dma_rst"]
 pub struct SPI3_DMA_RST_R(crate::FieldReader<bool, bool>);
 impl SPI3_DMA_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI3_DMA_RST_R(crate::FieldReader::new(bits))
     }
@@ -1038,13 +1066,14 @@ impl<'a> SPI3_DMA_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 27)) | ((value as u32 & 0x01) << 27);
+        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
         self.w
     }
 }
 #[doc = "Field `APB_SARADC_RST` reader - reg_apb_saradc_rst"]
 pub struct APB_SARADC_RST_R(crate::FieldReader<bool, bool>);
 impl APB_SARADC_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         APB_SARADC_RST_R(crate::FieldReader::new(bits))
     }
@@ -1074,13 +1103,14 @@ impl<'a> APB_SARADC_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 28)) | ((value as u32 & 0x01) << 28);
+        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
         self.w
     }
 }
 #[doc = "Field `SYSTIMER_RST` reader - reg_systimer_rst"]
 pub struct SYSTIMER_RST_R(crate::FieldReader<bool, bool>);
 impl SYSTIMER_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SYSTIMER_RST_R(crate::FieldReader::new(bits))
     }
@@ -1110,13 +1140,14 @@ impl<'a> SYSTIMER_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
         self.w
     }
 }
 #[doc = "Field `ADC2_ARB_RST` reader - reg_adc2_arb_rst"]
 pub struct ADC2_ARB_RST_R(crate::FieldReader<bool, bool>);
 impl ADC2_ARB_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         ADC2_ARB_RST_R(crate::FieldReader::new(bits))
     }
@@ -1146,13 +1177,14 @@ impl<'a> ADC2_ARB_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
+        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
         self.w
     }
 }
 #[doc = "Field `SPI4_RST` reader - reg_spi4_rst"]
 pub struct SPI4_RST_R(crate::FieldReader<bool, bool>);
 impl SPI4_RST_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SPI4_RST_R(crate::FieldReader::new(bits))
     }
@@ -1182,7 +1214,7 @@ impl<'a> SPI4_RST_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -1190,162 +1222,162 @@ impl R {
     #[doc = "Bit 0 - reg_timers_rst"]
     #[inline(always)]
     pub fn timers_rst(&self) -> TIMERS_RST_R {
-        TIMERS_RST_R::new((self.bits & 0x01) != 0)
+        TIMERS_RST_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - reg_spi01_rst"]
     #[inline(always)]
     pub fn spi01_rst(&self) -> SPI01_RST_R {
-        SPI01_RST_R::new(((self.bits >> 1) & 0x01) != 0)
+        SPI01_RST_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - reg_uart_rst"]
     #[inline(always)]
     pub fn uart_rst(&self) -> UART_RST_R {
-        UART_RST_R::new(((self.bits >> 2) & 0x01) != 0)
+        UART_RST_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - reg_wdg_rst"]
     #[inline(always)]
     pub fn wdg_rst(&self) -> WDG_RST_R {
-        WDG_RST_R::new(((self.bits >> 3) & 0x01) != 0)
+        WDG_RST_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - reg_i2s0_rst"]
     #[inline(always)]
     pub fn i2s0_rst(&self) -> I2S0_RST_R {
-        I2S0_RST_R::new(((self.bits >> 4) & 0x01) != 0)
+        I2S0_RST_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - reg_uart1_rst"]
     #[inline(always)]
     pub fn uart1_rst(&self) -> UART1_RST_R {
-        UART1_RST_R::new(((self.bits >> 5) & 0x01) != 0)
+        UART1_RST_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - reg_spi2_rst"]
     #[inline(always)]
     pub fn spi2_rst(&self) -> SPI2_RST_R {
-        SPI2_RST_R::new(((self.bits >> 6) & 0x01) != 0)
+        SPI2_RST_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - reg_ext0_rst"]
     #[inline(always)]
-    pub fn ext0_rst(&self) -> EXT0_RST_R {
-        EXT0_RST_R::new(((self.bits >> 7) & 0x01) != 0)
+    pub fn i2c_ext0_rst(&self) -> I2C_EXT0_RST_R {
+        I2C_EXT0_RST_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - reg_uhci0_rst"]
     #[inline(always)]
     pub fn uhci0_rst(&self) -> UHCI0_RST_R {
-        UHCI0_RST_R::new(((self.bits >> 8) & 0x01) != 0)
+        UHCI0_RST_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - reg_rmt_rst"]
     #[inline(always)]
     pub fn rmt_rst(&self) -> RMT_RST_R {
-        RMT_RST_R::new(((self.bits >> 9) & 0x01) != 0)
+        RMT_RST_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - reg_pcnt_rst"]
     #[inline(always)]
     pub fn pcnt_rst(&self) -> PCNT_RST_R {
-        PCNT_RST_R::new(((self.bits >> 10) & 0x01) != 0)
+        PCNT_RST_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - reg_ledc_rst"]
     #[inline(always)]
     pub fn ledc_rst(&self) -> LEDC_RST_R {
-        LEDC_RST_R::new(((self.bits >> 11) & 0x01) != 0)
+        LEDC_RST_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - reg_uhci1_rst"]
     #[inline(always)]
     pub fn uhci1_rst(&self) -> UHCI1_RST_R {
-        UHCI1_RST_R::new(((self.bits >> 12) & 0x01) != 0)
+        UHCI1_RST_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - reg_timergroup_rst"]
     #[inline(always)]
     pub fn timergroup_rst(&self) -> TIMERGROUP_RST_R {
-        TIMERGROUP_RST_R::new(((self.bits >> 13) & 0x01) != 0)
+        TIMERGROUP_RST_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - reg_efuse_rst"]
     #[inline(always)]
     pub fn efuse_rst(&self) -> EFUSE_RST_R {
-        EFUSE_RST_R::new(((self.bits >> 14) & 0x01) != 0)
+        EFUSE_RST_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bit 15 - reg_timergroup1_rst"]
     #[inline(always)]
     pub fn timergroup1_rst(&self) -> TIMERGROUP1_RST_R {
-        TIMERGROUP1_RST_R::new(((self.bits >> 15) & 0x01) != 0)
+        TIMERGROUP1_RST_R::new(((self.bits >> 15) & 1) != 0)
     }
     #[doc = "Bit 16 - reg_spi3_rst"]
     #[inline(always)]
     pub fn spi3_rst(&self) -> SPI3_RST_R {
-        SPI3_RST_R::new(((self.bits >> 16) & 0x01) != 0)
+        SPI3_RST_R::new(((self.bits >> 16) & 1) != 0)
     }
     #[doc = "Bit 17 - reg_pwm0_rst"]
     #[inline(always)]
     pub fn pwm0_rst(&self) -> PWM0_RST_R {
-        PWM0_RST_R::new(((self.bits >> 17) & 0x01) != 0)
+        PWM0_RST_R::new(((self.bits >> 17) & 1) != 0)
     }
     #[doc = "Bit 18 - reg_ext1_rst"]
     #[inline(always)]
     pub fn ext1_rst(&self) -> EXT1_RST_R {
-        EXT1_RST_R::new(((self.bits >> 18) & 0x01) != 0)
+        EXT1_RST_R::new(((self.bits >> 18) & 1) != 0)
     }
     #[doc = "Bit 19 - reg_can_rst"]
     #[inline(always)]
     pub fn can_rst(&self) -> CAN_RST_R {
-        CAN_RST_R::new(((self.bits >> 19) & 0x01) != 0)
+        CAN_RST_R::new(((self.bits >> 19) & 1) != 0)
     }
     #[doc = "Bit 20 - reg_pwm1_rst"]
     #[inline(always)]
     pub fn pwm1_rst(&self) -> PWM1_RST_R {
-        PWM1_RST_R::new(((self.bits >> 20) & 0x01) != 0)
+        PWM1_RST_R::new(((self.bits >> 20) & 1) != 0)
     }
     #[doc = "Bit 21 - reg_i2s1_rst"]
     #[inline(always)]
     pub fn i2s1_rst(&self) -> I2S1_RST_R {
-        I2S1_RST_R::new(((self.bits >> 21) & 0x01) != 0)
+        I2S1_RST_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bit 22 - reg_spi2_dma_rst"]
     #[inline(always)]
     pub fn spi2_dma_rst(&self) -> SPI2_DMA_RST_R {
-        SPI2_DMA_RST_R::new(((self.bits >> 22) & 0x01) != 0)
+        SPI2_DMA_RST_R::new(((self.bits >> 22) & 1) != 0)
     }
     #[doc = "Bit 23 - reg_usb_device_rst"]
     #[inline(always)]
     pub fn usb_device_rst(&self) -> USB_DEVICE_RST_R {
-        USB_DEVICE_RST_R::new(((self.bits >> 23) & 0x01) != 0)
+        USB_DEVICE_RST_R::new(((self.bits >> 23) & 1) != 0)
     }
     #[doc = "Bit 24 - reg_uart_mem_rst"]
     #[inline(always)]
     pub fn uart_mem_rst(&self) -> UART_MEM_RST_R {
-        UART_MEM_RST_R::new(((self.bits >> 24) & 0x01) != 0)
+        UART_MEM_RST_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bit 25 - reg_pwm2_rst"]
     #[inline(always)]
     pub fn pwm2_rst(&self) -> PWM2_RST_R {
-        PWM2_RST_R::new(((self.bits >> 25) & 0x01) != 0)
+        PWM2_RST_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 26 - reg_pwm3_rst"]
     #[inline(always)]
     pub fn pwm3_rst(&self) -> PWM3_RST_R {
-        PWM3_RST_R::new(((self.bits >> 26) & 0x01) != 0)
+        PWM3_RST_R::new(((self.bits >> 26) & 1) != 0)
     }
     #[doc = "Bit 27 - reg_spi3_dma_rst"]
     #[inline(always)]
     pub fn spi3_dma_rst(&self) -> SPI3_DMA_RST_R {
-        SPI3_DMA_RST_R::new(((self.bits >> 27) & 0x01) != 0)
+        SPI3_DMA_RST_R::new(((self.bits >> 27) & 1) != 0)
     }
     #[doc = "Bit 28 - reg_apb_saradc_rst"]
     #[inline(always)]
     pub fn apb_saradc_rst(&self) -> APB_SARADC_RST_R {
-        APB_SARADC_RST_R::new(((self.bits >> 28) & 0x01) != 0)
+        APB_SARADC_RST_R::new(((self.bits >> 28) & 1) != 0)
     }
     #[doc = "Bit 29 - reg_systimer_rst"]
     #[inline(always)]
     pub fn systimer_rst(&self) -> SYSTIMER_RST_R {
-        SYSTIMER_RST_R::new(((self.bits >> 29) & 0x01) != 0)
+        SYSTIMER_RST_R::new(((self.bits >> 29) & 1) != 0)
     }
     #[doc = "Bit 30 - reg_adc2_arb_rst"]
     #[inline(always)]
     pub fn adc2_arb_rst(&self) -> ADC2_ARB_RST_R {
-        ADC2_ARB_RST_R::new(((self.bits >> 30) & 0x01) != 0)
+        ADC2_ARB_RST_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 31 - reg_spi4_rst"]
     #[inline(always)]
     pub fn spi4_rst(&self) -> SPI4_RST_R {
-        SPI4_RST_R::new(((self.bits >> 31) & 0x01) != 0)
+        SPI4_RST_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -1386,8 +1418,8 @@ impl W {
     }
     #[doc = "Bit 7 - reg_ext0_rst"]
     #[inline(always)]
-    pub fn ext0_rst(&mut self) -> EXT0_RST_W {
-        EXT0_RST_W { w: self }
+    pub fn i2c_ext0_rst(&mut self) -> I2C_EXT0_RST_W {
+        I2C_EXT0_RST_W { w: self }
     }
     #[doc = "Bit 8 - reg_uhci0_rst"]
     #[inline(always)]
@@ -1516,16 +1548,25 @@ impl W {
         self
     }
 }
-#[doc = "reserved\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [perip_rst_en0](index.html) module"]
+#[doc = "reserved\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [perip_rst_en0]
+(index.html) module"]
 pub struct PERIP_RST_EN0_SPEC;
 impl crate::RegisterSpec for PERIP_RST_EN0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [perip_rst_en0::R](R) reader structure"]
+#[doc = "`read()` method returns [perip_rst_en0::R]
+(R) reader structure"]
 impl crate::Readable for PERIP_RST_EN0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [perip_rst_en0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [perip_rst_en0::W]
+(W) writer structure"]
 impl crate::Writable for PERIP_RST_EN0_SPEC {
     type Writer = W;
 }
