@@ -16,6 +16,7 @@ impl From<crate::R<T0HI_SPEC>> for R {
 #[doc = "Field `T0_HI` reader - t0_hi"]
 pub struct T0_HI_R(crate::FieldReader<u32, u32>);
 impl T0_HI_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u32) -> Self {
         T0_HI_R(crate::FieldReader::new(bits))
     }
@@ -34,12 +35,16 @@ impl R {
         T0_HI_R::new((self.bits & 0x003f_ffff) as u32)
     }
 }
-#[doc = "TIMG_T0HI_REG.\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [t0hi](index.html) module"]
+#[doc = "TIMG_T0HI_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [t0hi]
+(index.html) module"]
 pub struct T0HI_SPEC;
 impl crate::RegisterSpec for T0HI_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [t0hi::R](R) reader structure"]
+#[doc = "`read()` method returns [t0hi::R]
+(R) reader structure"]
 impl crate::Readable for T0HI_SPEC {
     type Reader = R;
 }
