@@ -37,6 +37,7 @@ impl From<crate::W<WDTCONFIG0_SPEC>> for W {
 #[doc = "Field `WDT_APPCPU_RESET_EN` reader - reg_wdt_appcpu_reset_en."]
 pub struct WDT_APPCPU_RESET_EN_R(crate::FieldReader<bool, bool>);
 impl WDT_APPCPU_RESET_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDT_APPCPU_RESET_EN_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> WDT_APPCPU_RESET_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `WDT_PROCPU_RESET_EN` reader - reg_wdt_procpu_reset_en."]
 pub struct WDT_PROCPU_RESET_EN_R(crate::FieldReader<bool, bool>);
 impl WDT_PROCPU_RESET_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDT_PROCPU_RESET_EN_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> WDT_PROCPU_RESET_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `WDT_FLASHBOOT_MOD_EN` reader - reg_wdt_flashboot_mod_en."]
 pub struct WDT_FLASHBOOT_MOD_EN_R(crate::FieldReader<bool, bool>);
 impl WDT_FLASHBOOT_MOD_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDT_FLASHBOOT_MOD_EN_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> WDT_FLASHBOOT_MOD_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
 #[doc = "Field `WDT_SYS_RESET_LENGTH` reader - reg_wdt_sys_reset_length."]
 pub struct WDT_SYS_RESET_LENGTH_R(crate::FieldReader<u8, u8>);
 impl WDT_SYS_RESET_LENGTH_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_SYS_RESET_LENGTH_R(crate::FieldReader::new(bits))
     }
@@ -164,13 +168,14 @@ impl<'a> WDT_SYS_RESET_LENGTH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 15)) | ((value as u32 & 0x07) << 15);
+        self.w.bits = (self.w.bits & !(7 << 15)) | ((value as u32 & 7) << 15);
         self.w
     }
 }
 #[doc = "Field `WDT_CPU_RESET_LENGTH` reader - reg_wdt_cpu_reset_length."]
 pub struct WDT_CPU_RESET_LENGTH_R(crate::FieldReader<u8, u8>);
 impl WDT_CPU_RESET_LENGTH_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_CPU_RESET_LENGTH_R(crate::FieldReader::new(bits))
     }
@@ -190,13 +195,14 @@ impl<'a> WDT_CPU_RESET_LENGTH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 18)) | ((value as u32 & 0x07) << 18);
+        self.w.bits = (self.w.bits & !(7 << 18)) | ((value as u32 & 7) << 18);
         self.w
     }
 }
 #[doc = "Field `WDT_USE_XTAL` reader - reg_wdt_use_xtal."]
 pub struct WDT_USE_XTAL_R(crate::FieldReader<bool, bool>);
 impl WDT_USE_XTAL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDT_USE_XTAL_R(crate::FieldReader::new(bits))
     }
@@ -226,7 +232,7 @@ impl<'a> WDT_USE_XTAL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
         self.w
     }
 }
@@ -248,13 +254,14 @@ impl<'a> WDT_CONF_UPDATE_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
         self.w
     }
 }
 #[doc = "Field `WDT_STG3` reader - reg_wdt_stg3."]
 pub struct WDT_STG3_R(crate::FieldReader<u8, u8>);
 impl WDT_STG3_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_STG3_R(crate::FieldReader::new(bits))
     }
@@ -274,13 +281,14 @@ impl<'a> WDT_STG3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 23)) | ((value as u32 & 0x03) << 23);
+        self.w.bits = (self.w.bits & !(3 << 23)) | ((value as u32 & 3) << 23);
         self.w
     }
 }
 #[doc = "Field `WDT_STG2` reader - reg_wdt_stg2."]
 pub struct WDT_STG2_R(crate::FieldReader<u8, u8>);
 impl WDT_STG2_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_STG2_R(crate::FieldReader::new(bits))
     }
@@ -300,13 +308,14 @@ impl<'a> WDT_STG2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 25)) | ((value as u32 & 0x03) << 25);
+        self.w.bits = (self.w.bits & !(3 << 25)) | ((value as u32 & 3) << 25);
         self.w
     }
 }
 #[doc = "Field `WDT_STG1` reader - reg_wdt_stg1."]
 pub struct WDT_STG1_R(crate::FieldReader<u8, u8>);
 impl WDT_STG1_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_STG1_R(crate::FieldReader::new(bits))
     }
@@ -326,13 +335,14 @@ impl<'a> WDT_STG1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 27)) | ((value as u32 & 0x03) << 27);
+        self.w.bits = (self.w.bits & !(3 << 27)) | ((value as u32 & 3) << 27);
         self.w
     }
 }
 #[doc = "Field `WDT_STG0` reader - reg_wdt_stg0."]
 pub struct WDT_STG0_R(crate::FieldReader<u8, u8>);
 impl WDT_STG0_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         WDT_STG0_R(crate::FieldReader::new(bits))
     }
@@ -352,13 +362,14 @@ impl<'a> WDT_STG0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 29)) | ((value as u32 & 0x03) << 29);
+        self.w.bits = (self.w.bits & !(3 << 29)) | ((value as u32 & 3) << 29);
         self.w
     }
 }
 #[doc = "Field `WDT_EN` reader - reg_wdt_en."]
 pub struct WDT_EN_R(crate::FieldReader<bool, bool>);
 impl WDT_EN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         WDT_EN_R(crate::FieldReader::new(bits))
     }
@@ -388,7 +399,7 @@ impl<'a> WDT_EN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
+        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
         self.w
     }
 }
@@ -396,57 +407,57 @@ impl R {
     #[doc = "Bit 12 - reg_wdt_appcpu_reset_en."]
     #[inline(always)]
     pub fn wdt_appcpu_reset_en(&self) -> WDT_APPCPU_RESET_EN_R {
-        WDT_APPCPU_RESET_EN_R::new(((self.bits >> 12) & 0x01) != 0)
+        WDT_APPCPU_RESET_EN_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - reg_wdt_procpu_reset_en."]
     #[inline(always)]
     pub fn wdt_procpu_reset_en(&self) -> WDT_PROCPU_RESET_EN_R {
-        WDT_PROCPU_RESET_EN_R::new(((self.bits >> 13) & 0x01) != 0)
+        WDT_PROCPU_RESET_EN_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - reg_wdt_flashboot_mod_en."]
     #[inline(always)]
     pub fn wdt_flashboot_mod_en(&self) -> WDT_FLASHBOOT_MOD_EN_R {
-        WDT_FLASHBOOT_MOD_EN_R::new(((self.bits >> 14) & 0x01) != 0)
+        WDT_FLASHBOOT_MOD_EN_R::new(((self.bits >> 14) & 1) != 0)
     }
     #[doc = "Bits 15:17 - reg_wdt_sys_reset_length."]
     #[inline(always)]
     pub fn wdt_sys_reset_length(&self) -> WDT_SYS_RESET_LENGTH_R {
-        WDT_SYS_RESET_LENGTH_R::new(((self.bits >> 15) & 0x07) as u8)
+        WDT_SYS_RESET_LENGTH_R::new(((self.bits >> 15) & 7) as u8)
     }
     #[doc = "Bits 18:20 - reg_wdt_cpu_reset_length."]
     #[inline(always)]
     pub fn wdt_cpu_reset_length(&self) -> WDT_CPU_RESET_LENGTH_R {
-        WDT_CPU_RESET_LENGTH_R::new(((self.bits >> 18) & 0x07) as u8)
+        WDT_CPU_RESET_LENGTH_R::new(((self.bits >> 18) & 7) as u8)
     }
     #[doc = "Bit 21 - reg_wdt_use_xtal."]
     #[inline(always)]
     pub fn wdt_use_xtal(&self) -> WDT_USE_XTAL_R {
-        WDT_USE_XTAL_R::new(((self.bits >> 21) & 0x01) != 0)
+        WDT_USE_XTAL_R::new(((self.bits >> 21) & 1) != 0)
     }
     #[doc = "Bits 23:24 - reg_wdt_stg3."]
     #[inline(always)]
     pub fn wdt_stg3(&self) -> WDT_STG3_R {
-        WDT_STG3_R::new(((self.bits >> 23) & 0x03) as u8)
+        WDT_STG3_R::new(((self.bits >> 23) & 3) as u8)
     }
     #[doc = "Bits 25:26 - reg_wdt_stg2."]
     #[inline(always)]
     pub fn wdt_stg2(&self) -> WDT_STG2_R {
-        WDT_STG2_R::new(((self.bits >> 25) & 0x03) as u8)
+        WDT_STG2_R::new(((self.bits >> 25) & 3) as u8)
     }
     #[doc = "Bits 27:28 - reg_wdt_stg1."]
     #[inline(always)]
     pub fn wdt_stg1(&self) -> WDT_STG1_R {
-        WDT_STG1_R::new(((self.bits >> 27) & 0x03) as u8)
+        WDT_STG1_R::new(((self.bits >> 27) & 3) as u8)
     }
     #[doc = "Bits 29:30 - reg_wdt_stg0."]
     #[inline(always)]
     pub fn wdt_stg0(&self) -> WDT_STG0_R {
-        WDT_STG0_R::new(((self.bits >> 29) & 0x03) as u8)
+        WDT_STG0_R::new(((self.bits >> 29) & 3) as u8)
     }
     #[doc = "Bit 31 - reg_wdt_en."]
     #[inline(always)]
     pub fn wdt_en(&self) -> WDT_EN_R {
-        WDT_EN_R::new(((self.bits >> 31) & 0x01) != 0)
+        WDT_EN_R::new(((self.bits >> 31) & 1) != 0)
     }
 }
 impl W {
@@ -517,16 +528,25 @@ impl W {
         self
     }
 }
-#[doc = "TIMG_WDTCONFIG0_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdtconfig0](index.html) module"]
+#[doc = "TIMG_WDTCONFIG0_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [wdtconfig0]
+(index.html) module"]
 pub struct WDTCONFIG0_SPEC;
 impl crate::RegisterSpec for WDTCONFIG0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [wdtconfig0::R](R) reader structure"]
+#[doc = "`read()` method returns [wdtconfig0::R]
+(R) reader structure"]
 impl crate::Readable for WDTCONFIG0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [wdtconfig0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [wdtconfig0::W]
+(W) writer structure"]
 impl crate::Writable for WDTCONFIG0_SPEC {
     type Writer = W;
 }
