@@ -37,6 +37,7 @@ impl From<crate::W<CONF0_SPEC>> for W {
 #[doc = "Field `PHY_SEL` reader - Select internal/external PHY"]
 pub struct PHY_SEL_R(crate::FieldReader<bool, bool>);
 impl PHY_SEL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PHY_SEL_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> PHY_SEL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `EXCHG_PINS_OVERRIDE` reader - Enable software control USB D+ D- exchange"]
 pub struct EXCHG_PINS_OVERRIDE_R(crate::FieldReader<bool, bool>);
 impl EXCHG_PINS_OVERRIDE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EXCHG_PINS_OVERRIDE_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> EXCHG_PINS_OVERRIDE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `EXCHG_PINS` reader - USB D+ D- exchange"]
 pub struct EXCHG_PINS_R(crate::FieldReader<bool, bool>);
 impl EXCHG_PINS_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         EXCHG_PINS_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> EXCHG_PINS_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `VREFH` reader - Control single-end input high threshold,1.76V to 2V, step 80mV"]
 pub struct VREFH_R(crate::FieldReader<u8, u8>);
 impl VREFH_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         VREFH_R(crate::FieldReader::new(bits))
     }
@@ -164,13 +168,14 @@ impl<'a> VREFH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 3)) | ((value as u32 & 0x03) << 3);
+        self.w.bits = (self.w.bits & !(3 << 3)) | ((value as u32 & 3) << 3);
         self.w
     }
 }
 #[doc = "Field `VREFL` reader - Control single-end input low threshold,0.8V to 1.04V, step 80mV"]
 pub struct VREFL_R(crate::FieldReader<u8, u8>);
 impl VREFL_R {
+    #[inline(always)]
     pub(crate) fn new(bits: u8) -> Self {
         VREFL_R(crate::FieldReader::new(bits))
     }
@@ -190,13 +195,14 @@ impl<'a> VREFL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 5)) | ((value as u32 & 0x03) << 5);
+        self.w.bits = (self.w.bits & !(3 << 5)) | ((value as u32 & 3) << 5);
         self.w
     }
 }
 #[doc = "Field `VREF_OVERRIDE` reader - Enable software control input threshold"]
 pub struct VREF_OVERRIDE_R(crate::FieldReader<bool, bool>);
 impl VREF_OVERRIDE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         VREF_OVERRIDE_R(crate::FieldReader::new(bits))
     }
@@ -226,13 +232,14 @@ impl<'a> VREF_OVERRIDE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `PAD_PULL_OVERRIDE` reader - Enable software control USB D+ D- pullup pulldown"]
 pub struct PAD_PULL_OVERRIDE_R(crate::FieldReader<bool, bool>);
 impl PAD_PULL_OVERRIDE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PAD_PULL_OVERRIDE_R(crate::FieldReader::new(bits))
     }
@@ -262,13 +269,14 @@ impl<'a> PAD_PULL_OVERRIDE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `DP_PULLUP` reader - Control USB D+ pull up."]
 pub struct DP_PULLUP_R(crate::FieldReader<bool, bool>);
 impl DP_PULLUP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DP_PULLUP_R(crate::FieldReader::new(bits))
     }
@@ -298,13 +306,14 @@ impl<'a> DP_PULLUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `DP_PULLDOWN` reader - Control USB D+ pull down."]
 pub struct DP_PULLDOWN_R(crate::FieldReader<bool, bool>);
 impl DP_PULLDOWN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DP_PULLDOWN_R(crate::FieldReader::new(bits))
     }
@@ -334,13 +343,14 @@ impl<'a> DP_PULLDOWN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `DM_PULLUP` reader - Control USB D- pull up."]
 pub struct DM_PULLUP_R(crate::FieldReader<bool, bool>);
 impl DM_PULLUP_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DM_PULLUP_R(crate::FieldReader::new(bits))
     }
@@ -370,13 +380,14 @@ impl<'a> DM_PULLUP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
 #[doc = "Field `DM_PULLDOWN` reader - Control USB D- pull down."]
 pub struct DM_PULLDOWN_R(crate::FieldReader<bool, bool>);
 impl DM_PULLDOWN_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         DM_PULLDOWN_R(crate::FieldReader::new(bits))
     }
@@ -406,13 +417,14 @@ impl<'a> DM_PULLDOWN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
         self.w
     }
 }
 #[doc = "Field `PULLUP_VALUE` reader - Control pull up value."]
 pub struct PULLUP_VALUE_R(crate::FieldReader<bool, bool>);
 impl PULLUP_VALUE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PULLUP_VALUE_R(crate::FieldReader::new(bits))
     }
@@ -442,13 +454,14 @@ impl<'a> PULLUP_VALUE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
         self.w
     }
 }
 #[doc = "Field `USB_PAD_ENABLE` reader - Enable USB pad function."]
 pub struct USB_PAD_ENABLE_R(crate::FieldReader<bool, bool>);
 impl USB_PAD_ENABLE_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USB_PAD_ENABLE_R(crate::FieldReader::new(bits))
     }
@@ -478,7 +491,7 @@ impl<'a> USB_PAD_ENABLE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
         self.w
     }
 }
@@ -486,67 +499,67 @@ impl R {
     #[doc = "Bit 0 - Select internal/external PHY"]
     #[inline(always)]
     pub fn phy_sel(&self) -> PHY_SEL_R {
-        PHY_SEL_R::new((self.bits & 0x01) != 0)
+        PHY_SEL_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - Enable software control USB D+ D- exchange"]
     #[inline(always)]
     pub fn exchg_pins_override(&self) -> EXCHG_PINS_OVERRIDE_R {
-        EXCHG_PINS_OVERRIDE_R::new(((self.bits >> 1) & 0x01) != 0)
+        EXCHG_PINS_OVERRIDE_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - USB D+ D- exchange"]
     #[inline(always)]
     pub fn exchg_pins(&self) -> EXCHG_PINS_R {
-        EXCHG_PINS_R::new(((self.bits >> 2) & 0x01) != 0)
+        EXCHG_PINS_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bits 3:4 - Control single-end input high threshold,1.76V to 2V, step 80mV"]
     #[inline(always)]
     pub fn vrefh(&self) -> VREFH_R {
-        VREFH_R::new(((self.bits >> 3) & 0x03) as u8)
+        VREFH_R::new(((self.bits >> 3) & 3) as u8)
     }
     #[doc = "Bits 5:6 - Control single-end input low threshold,0.8V to 1.04V, step 80mV"]
     #[inline(always)]
     pub fn vrefl(&self) -> VREFL_R {
-        VREFL_R::new(((self.bits >> 5) & 0x03) as u8)
+        VREFL_R::new(((self.bits >> 5) & 3) as u8)
     }
     #[doc = "Bit 7 - Enable software control input threshold"]
     #[inline(always)]
     pub fn vref_override(&self) -> VREF_OVERRIDE_R {
-        VREF_OVERRIDE_R::new(((self.bits >> 7) & 0x01) != 0)
+        VREF_OVERRIDE_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - Enable software control USB D+ D- pullup pulldown"]
     #[inline(always)]
     pub fn pad_pull_override(&self) -> PAD_PULL_OVERRIDE_R {
-        PAD_PULL_OVERRIDE_R::new(((self.bits >> 8) & 0x01) != 0)
+        PAD_PULL_OVERRIDE_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - Control USB D+ pull up."]
     #[inline(always)]
     pub fn dp_pullup(&self) -> DP_PULLUP_R {
-        DP_PULLUP_R::new(((self.bits >> 9) & 0x01) != 0)
+        DP_PULLUP_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - Control USB D+ pull down."]
     #[inline(always)]
     pub fn dp_pulldown(&self) -> DP_PULLDOWN_R {
-        DP_PULLDOWN_R::new(((self.bits >> 10) & 0x01) != 0)
+        DP_PULLDOWN_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - Control USB D- pull up."]
     #[inline(always)]
     pub fn dm_pullup(&self) -> DM_PULLUP_R {
-        DM_PULLUP_R::new(((self.bits >> 11) & 0x01) != 0)
+        DM_PULLUP_R::new(((self.bits >> 11) & 1) != 0)
     }
     #[doc = "Bit 12 - Control USB D- pull down."]
     #[inline(always)]
     pub fn dm_pulldown(&self) -> DM_PULLDOWN_R {
-        DM_PULLDOWN_R::new(((self.bits >> 12) & 0x01) != 0)
+        DM_PULLDOWN_R::new(((self.bits >> 12) & 1) != 0)
     }
     #[doc = "Bit 13 - Control pull up value."]
     #[inline(always)]
     pub fn pullup_value(&self) -> PULLUP_VALUE_R {
-        PULLUP_VALUE_R::new(((self.bits >> 13) & 0x01) != 0)
+        PULLUP_VALUE_R::new(((self.bits >> 13) & 1) != 0)
     }
     #[doc = "Bit 14 - Enable USB pad function."]
     #[inline(always)]
     pub fn usb_pad_enable(&self) -> USB_PAD_ENABLE_R {
-        USB_PAD_ENABLE_R::new(((self.bits >> 14) & 0x01) != 0)
+        USB_PAD_ENABLE_R::new(((self.bits >> 14) & 1) != 0)
     }
 }
 impl W {
@@ -622,16 +635,25 @@ impl W {
         self
     }
 }
-#[doc = "USB_DEVICE_CONF0_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [conf0](index.html) module"]
+#[doc = "USB_DEVICE_CONF0_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [conf0]
+(index.html) module"]
 pub struct CONF0_SPEC;
 impl crate::RegisterSpec for CONF0_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [conf0::R](R) reader structure"]
+#[doc = "`read()` method returns [conf0::R]
+(R) reader structure"]
 impl crate::Readable for CONF0_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [conf0::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [conf0::W]
+(W) writer structure"]
 impl crate::Writable for CONF0_SPEC {
     type Writer = W;
 }
