@@ -37,6 +37,7 @@ impl From<crate::W<INT_ENA_SPEC>> for W {
 #[doc = "Field `JTAG_IN_FLUSH_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_JTAG_IN_FLUSH_INT interrupt."]
 pub struct JTAG_IN_FLUSH_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl JTAG_IN_FLUSH_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         JTAG_IN_FLUSH_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -66,13 +67,14 @@ impl<'a> JTAG_IN_FLUSH_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
         self.w
     }
 }
 #[doc = "Field `SOF_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_SOF_INT interrupt."]
 pub struct SOF_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SOF_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SOF_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -102,13 +104,14 @@ impl<'a> SOF_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
         self.w
     }
 }
 #[doc = "Field `SERIAL_OUT_RECV_PKT_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_SERIAL_OUT_RECV_PKT_INT interrupt."]
 pub struct SERIAL_OUT_RECV_PKT_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SERIAL_OUT_RECV_PKT_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SERIAL_OUT_RECV_PKT_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -138,13 +141,14 @@ impl<'a> SERIAL_OUT_RECV_PKT_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
         self.w
     }
 }
 #[doc = "Field `SERIAL_IN_EMPTY_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_SERIAL_IN_EMPTY_INT interrupt."]
 pub struct SERIAL_IN_EMPTY_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl SERIAL_IN_EMPTY_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         SERIAL_IN_EMPTY_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -174,13 +178,14 @@ impl<'a> SERIAL_IN_EMPTY_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
         self.w
     }
 }
 #[doc = "Field `PID_ERR_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_PID_ERR_INT interrupt."]
 pub struct PID_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl PID_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         PID_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -210,13 +215,14 @@ impl<'a> PID_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
         self.w
     }
 }
 #[doc = "Field `CRC5_ERR_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_CRC5_ERR_INT interrupt."]
 pub struct CRC5_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CRC5_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CRC5_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -246,13 +252,14 @@ impl<'a> CRC5_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
         self.w
     }
 }
 #[doc = "Field `CRC16_ERR_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_CRC16_ERR_INT interrupt."]
 pub struct CRC16_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl CRC16_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         CRC16_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -282,13 +289,14 @@ impl<'a> CRC16_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
         self.w
     }
 }
 #[doc = "Field `STUFF_ERR_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_STUFF_ERR_INT interrupt."]
 pub struct STUFF_ERR_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl STUFF_ERR_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         STUFF_ERR_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -318,13 +326,14 @@ impl<'a> STUFF_ERR_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
         self.w
     }
 }
 #[doc = "Field `IN_TOKEN_REC_IN_EP1_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_IN_TOKEN_REC_IN_EP1_INT interrupt."]
 pub struct IN_TOKEN_REC_IN_EP1_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl IN_TOKEN_REC_IN_EP1_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         IN_TOKEN_REC_IN_EP1_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -354,13 +363,14 @@ impl<'a> IN_TOKEN_REC_IN_EP1_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
         self.w
     }
 }
 #[doc = "Field `USB_BUS_RESET_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_USB_BUS_RESET_INT interrupt."]
 pub struct USB_BUS_RESET_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl USB_BUS_RESET_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         USB_BUS_RESET_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -390,13 +400,14 @@ impl<'a> USB_BUS_RESET_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
         self.w
     }
 }
 #[doc = "Field `OUT_EP1_ZERO_PAYLOAD_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_OUT_EP1_ZERO_PAYLOAD_INT interrupt."]
 pub struct OUT_EP1_ZERO_PAYLOAD_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_EP1_ZERO_PAYLOAD_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_EP1_ZERO_PAYLOAD_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -426,13 +437,14 @@ impl<'a> OUT_EP1_ZERO_PAYLOAD_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
         self.w
     }
 }
 #[doc = "Field `OUT_EP2_ZERO_PAYLOAD_INT_ENA` reader - The interrupt enable bit for the USB_DEVICE_OUT_EP2_ZERO_PAYLOAD_INT interrupt."]
 pub struct OUT_EP2_ZERO_PAYLOAD_INT_ENA_R(crate::FieldReader<bool, bool>);
 impl OUT_EP2_ZERO_PAYLOAD_INT_ENA_R {
+    #[inline(always)]
     pub(crate) fn new(bits: bool) -> Self {
         OUT_EP2_ZERO_PAYLOAD_INT_ENA_R(crate::FieldReader::new(bits))
     }
@@ -462,7 +474,7 @@ impl<'a> OUT_EP2_ZERO_PAYLOAD_INT_ENA_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
         self.w
     }
 }
@@ -470,62 +482,62 @@ impl R {
     #[doc = "Bit 0 - The interrupt enable bit for the USB_DEVICE_JTAG_IN_FLUSH_INT interrupt."]
     #[inline(always)]
     pub fn jtag_in_flush_int_ena(&self) -> JTAG_IN_FLUSH_INT_ENA_R {
-        JTAG_IN_FLUSH_INT_ENA_R::new((self.bits & 0x01) != 0)
+        JTAG_IN_FLUSH_INT_ENA_R::new((self.bits & 1) != 0)
     }
     #[doc = "Bit 1 - The interrupt enable bit for the USB_DEVICE_SOF_INT interrupt."]
     #[inline(always)]
     pub fn sof_int_ena(&self) -> SOF_INT_ENA_R {
-        SOF_INT_ENA_R::new(((self.bits >> 1) & 0x01) != 0)
+        SOF_INT_ENA_R::new(((self.bits >> 1) & 1) != 0)
     }
     #[doc = "Bit 2 - The interrupt enable bit for the USB_DEVICE_SERIAL_OUT_RECV_PKT_INT interrupt."]
     #[inline(always)]
     pub fn serial_out_recv_pkt_int_ena(&self) -> SERIAL_OUT_RECV_PKT_INT_ENA_R {
-        SERIAL_OUT_RECV_PKT_INT_ENA_R::new(((self.bits >> 2) & 0x01) != 0)
+        SERIAL_OUT_RECV_PKT_INT_ENA_R::new(((self.bits >> 2) & 1) != 0)
     }
     #[doc = "Bit 3 - The interrupt enable bit for the USB_DEVICE_SERIAL_IN_EMPTY_INT interrupt."]
     #[inline(always)]
     pub fn serial_in_empty_int_ena(&self) -> SERIAL_IN_EMPTY_INT_ENA_R {
-        SERIAL_IN_EMPTY_INT_ENA_R::new(((self.bits >> 3) & 0x01) != 0)
+        SERIAL_IN_EMPTY_INT_ENA_R::new(((self.bits >> 3) & 1) != 0)
     }
     #[doc = "Bit 4 - The interrupt enable bit for the USB_DEVICE_PID_ERR_INT interrupt."]
     #[inline(always)]
     pub fn pid_err_int_ena(&self) -> PID_ERR_INT_ENA_R {
-        PID_ERR_INT_ENA_R::new(((self.bits >> 4) & 0x01) != 0)
+        PID_ERR_INT_ENA_R::new(((self.bits >> 4) & 1) != 0)
     }
     #[doc = "Bit 5 - The interrupt enable bit for the USB_DEVICE_CRC5_ERR_INT interrupt."]
     #[inline(always)]
     pub fn crc5_err_int_ena(&self) -> CRC5_ERR_INT_ENA_R {
-        CRC5_ERR_INT_ENA_R::new(((self.bits >> 5) & 0x01) != 0)
+        CRC5_ERR_INT_ENA_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bit 6 - The interrupt enable bit for the USB_DEVICE_CRC16_ERR_INT interrupt."]
     #[inline(always)]
     pub fn crc16_err_int_ena(&self) -> CRC16_ERR_INT_ENA_R {
-        CRC16_ERR_INT_ENA_R::new(((self.bits >> 6) & 0x01) != 0)
+        CRC16_ERR_INT_ENA_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 7 - The interrupt enable bit for the USB_DEVICE_STUFF_ERR_INT interrupt."]
     #[inline(always)]
     pub fn stuff_err_int_ena(&self) -> STUFF_ERR_INT_ENA_R {
-        STUFF_ERR_INT_ENA_R::new(((self.bits >> 7) & 0x01) != 0)
+        STUFF_ERR_INT_ENA_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 8 - The interrupt enable bit for the USB_DEVICE_IN_TOKEN_REC_IN_EP1_INT interrupt."]
     #[inline(always)]
     pub fn in_token_rec_in_ep1_int_ena(&self) -> IN_TOKEN_REC_IN_EP1_INT_ENA_R {
-        IN_TOKEN_REC_IN_EP1_INT_ENA_R::new(((self.bits >> 8) & 0x01) != 0)
+        IN_TOKEN_REC_IN_EP1_INT_ENA_R::new(((self.bits >> 8) & 1) != 0)
     }
     #[doc = "Bit 9 - The interrupt enable bit for the USB_DEVICE_USB_BUS_RESET_INT interrupt."]
     #[inline(always)]
     pub fn usb_bus_reset_int_ena(&self) -> USB_BUS_RESET_INT_ENA_R {
-        USB_BUS_RESET_INT_ENA_R::new(((self.bits >> 9) & 0x01) != 0)
+        USB_BUS_RESET_INT_ENA_R::new(((self.bits >> 9) & 1) != 0)
     }
     #[doc = "Bit 10 - The interrupt enable bit for the USB_DEVICE_OUT_EP1_ZERO_PAYLOAD_INT interrupt."]
     #[inline(always)]
     pub fn out_ep1_zero_payload_int_ena(&self) -> OUT_EP1_ZERO_PAYLOAD_INT_ENA_R {
-        OUT_EP1_ZERO_PAYLOAD_INT_ENA_R::new(((self.bits >> 10) & 0x01) != 0)
+        OUT_EP1_ZERO_PAYLOAD_INT_ENA_R::new(((self.bits >> 10) & 1) != 0)
     }
     #[doc = "Bit 11 - The interrupt enable bit for the USB_DEVICE_OUT_EP2_ZERO_PAYLOAD_INT interrupt."]
     #[inline(always)]
     pub fn out_ep2_zero_payload_int_ena(&self) -> OUT_EP2_ZERO_PAYLOAD_INT_ENA_R {
-        OUT_EP2_ZERO_PAYLOAD_INT_ENA_R::new(((self.bits >> 11) & 0x01) != 0)
+        OUT_EP2_ZERO_PAYLOAD_INT_ENA_R::new(((self.bits >> 11) & 1) != 0)
     }
 }
 impl W {
@@ -596,16 +608,25 @@ impl W {
         self
     }
 }
-#[doc = "USB_DEVICE_INT_ENA_REG.\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena](index.html) module"]
+#[doc = "USB_DEVICE_INT_ENA_REG.\n\nThis register you can [`read`]
+(crate::generic::Reg::read), [`write_with_zero`]
+(crate::generic::Reg::write_with_zero), [`reset`]
+(crate::generic::Reg::reset), [`write`]
+(crate::generic::Reg::write), [`modify`]
+(crate::generic::Reg::modify). See [API]
+(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [int_ena]
+(index.html) module"]
 pub struct INT_ENA_SPEC;
 impl crate::RegisterSpec for INT_ENA_SPEC {
     type Ux = u32;
 }
-#[doc = "`read()` method returns [int_ena::R](R) reader structure"]
+#[doc = "`read()` method returns [int_ena::R]
+(R) reader structure"]
 impl crate::Readable for INT_ENA_SPEC {
     type Reader = R;
 }
-#[doc = "`write(|w| ..)` method takes [int_ena::W](W) writer structure"]
+#[doc = "`write(|w| ..)` method takes [int_ena::W]
+(W) writer structure"]
 impl crate::Writable for INT_ENA_SPEC {
     type Writer = W;
 }
